# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: groups.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from . import definitions_pb2 as definitions__pb2
from . import miscellaneous_pb2 as miscellaneous__pb2
from . import peers_pb2 as peers__pb2
from . import media_and_files_pb2 as media__and__files__pb2
from . import users_pb2 as users__pb2
from .scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='groups.proto',
  package='dialog',
  syntax='proto3',
  serialized_options=_b('\342?\026\n\024im.dlg.grpc.services'),
  serialized_pb=_b('\n\x0cgroups.proto\x12\x06\x64ialog\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x11\x64\x65\x66initions.proto\x1a\x13miscellaneous.proto\x1a\x0bpeers.proto\x1a\x15media_and_files.proto\x1a\x0busers.proto\x1a\x15scalapb/scalapb.proto\"\xe4\x01\n\x06Member\x12\x1a\n\x03uid\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\"\n\x0binviter_uid\x18\x02 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1b\n\x04\x64\x61te\x18\x03 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12;\n\x08is_admin\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\r\x8a\xea\x30\t\n\x07visible\x12@\n\x0bpermissions\x18\x05 \x03(\x0e\x32\x1c.dialog.GroupAdminPermissionB\r\x8a\xea\x30\t\n\x07visible\"\xdc\x06\n\x05Group\x12\x19\n\x02id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12#\n\x08space_id\x18\x1b \x01(\x0b\x32\x11.dialog.UUIDValue\x12!\n\x0b\x61\x63\x63\x65ss_hash\x18\x02 \x01(\x03\x42\x0c\x8a\xea\x30\x08\n\x06\x64\x61nger\x12\x1b\n\x05title\x18\x03 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06hidden\x12-\n\x06\x61vatar\x18\x04 \x01(\x0b\x32\x0e.dialog.AvatarB\r\x8a\xea\x30\t\n\x07\x63ompact\x12\x42\n\x0emembers_amount\x18\x18 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueB\r\x8a\xea\x30\t\n\x07visible\x12<\n\tis_member\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\r\x8a\xea\x30\t\n\x07visible\x12<\n\tis_hidden\x18\x14 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\r\x8a\xea\x30\t\n\x07visible\x12\x34\n\ngroup_type\x18\x19 \x01(\x0e\x32\x11.dialog.GroupTypeB\r\x8a\xea\x30\t\n\x07visible\x12\x43\n\x10\x63\x61n_send_message\x18\x1a \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\r\x8a\xea\x30\t\n\x07visible\x12;\n\x08is_admin\x18\x10 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\r\x8a\xea\x30\t\n\x07visible\x12\"\n\x0b\x63reator_uid\x18\x08 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12.\n\x07members\x18\t \x03(\x0b\x32\x0e.dialog.MemberB\r\x8a\xea\x30\t\n\x07\x63ompact\x12\"\n\x0b\x63reate_date\x18\n \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12\x39\n\x05theme\x18\x11 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x0c\x8a\xea\x30\x08\n\x06hidden\x12\x39\n\x05\x61\x62out\x18\x12 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x0c\x8a\xea\x30\x08\n\x06hidden\x12>\n\tshortname\x18\x13 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\r\x8a\xea\x30\t\n\x07visible\"\xa8\x04\n\tGroupFull\x12\x19\n\x02id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\"\n\x0b\x63reate_date\x18\x06 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12 \n\towner_uid\x18\x05 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12.\n\x07members\x18\x0c \x03(\x0b\x32\x0e.dialog.MemberB\r\x8a\xea\x30\t\n\x07visible\x12\x39\n\x05theme\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x0c\x8a\xea\x30\x08\n\x06hidden\x12\x39\n\x05\x61\x62out\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x0c\x8a\xea\x30\x08\n\x06hidden\x12\x43\n\x10is_async_members\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\r\x8a\xea\x30\t\n\x07visible\x12\x43\n\x10\x63\x61n_view_members\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\r\x8a\xea\x30\t\n\x07visible\x12\x44\n\x11\x63\x61n_invite_people\x18\t \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\r\x8a\xea\x30\t\n\x07visible\x12\x44\n\x11is_shared_history\x18\n \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\r\x8a\xea\x30\t\n\x07visible\"j\n\x15RequestLoadFullGroups\x12\x33\n\x06groups\x18\x01 \x03(\x0b\x32\x14.dialog.GroupOutPeerB\r\x8a\xea\x30\t\n\x07\x63ompact:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"Z\n\x16ResponseLoadFullGroups\x12!\n\x06groups\x18\x01 \x03(\x0b\x32\x11.dialog.GroupFull:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"\xbe\x01\n\x12RequestLoadMembers\x12\x32\n\x05group\x18\x01 \x01(\x0b\x32\x14.dialog.GroupOutPeerB\r\x8a\xea\x30\t\n\x07visible\x12\x1c\n\x05limit\x18\x02 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x38\n\x04next\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.BytesValueB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\x85\x01\n\x13ResponseLoadMembers\x12$\n\x07members\x18\x01 \x03(\x0b\x32\x13.dialog.UserOutPeer\x12)\n\x04next\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.BytesValue:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"W\n\x17UpdateGroupTitleChanged\x12\x1f\n\x08group_id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1b\n\x05title\x18\x02 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06hidden\"j\n\x18UpdateGroupAvatarChanged\x12\x1f\n\x08group_id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12-\n\x06\x61vatar\x18\x02 \x01(\x0b\x32\x0e.dialog.AvatarB\r\x8a\xea\x30\t\n\x07visible\"u\n\x17UpdateGroupTopicChanged\x12\x1f\n\x08group_id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x39\n\x05topic\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x0c\x8a\xea\x30\x08\n\x06hidden\"u\n\x17UpdateGroupAboutChanged\x12\x1f\n\x08group_id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x39\n\x05\x61\x62out\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x0c\x8a\xea\x30\x08\n\x06hidden\"Z\n\x17UpdateGroupOwnerChanged\x12\x1f\n\x08group_id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1e\n\x07user_id\x18\x02 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\";\n\x18UpdateGroupHistoryShared\x12\x1f\n\x08group_id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\"n\n!UpdateGroupCanSendMessagesChanged\x12\x1f\n\x08group_id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12(\n\x11\x63\x61n_send_messages\x18\x02 \x01(\x08\x42\r\x8a\xea\x30\t\n\x07visible\"l\n UpdateGroupCanViewMembersChanged\x12\x1f\n\x08group_id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\'\n\x10\x63\x61n_view_members\x18\x02 \x01(\x08\x42\r\x8a\xea\x30\t\n\x07visible\"p\n\"UpdateGroupCanInviteMembersChanged\x12\x1f\n\x08group_id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12)\n\x12\x63\x61n_invite_members\x18\x02 \x01(\x08\x42\r\x8a\xea\x30\t\n\x07visible\"]\n\x18UpdateGroupMemberChanged\x12\x1f\n\x08group_id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12 \n\tis_member\x18\x02 \x01(\x08\x42\r\x8a\xea\x30\t\n\x07visible\"@\n\x1dUpdateGroupMembersBecameAsync\x12\x1f\n\x08group_id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\"l\n\x19UpdateGroupMembersUpdated\x12\x1f\n\x08group_id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12.\n\x07members\x18\x02 \x03(\x0b\x32\x0e.dialog.MemberB\r\x8a\xea\x30\t\n\x07visible\"\x99\x01\n\x15UpdateGroupMemberDiff\x12$\n\rremoved_users\x18\x01 \x03(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x34\n\radded_members\x18\x02 \x03(\x0b\x32\x0e.dialog.MemberB\r\x8a\xea\x30\t\n\x07visible\x12$\n\rmembers_count\x18\x03 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\"g\n\x1eUpdateGroupMembersCountChanged\x12\x1f\n\x08group_id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12$\n\rmembers_count\x18\x02 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\"\x81\x01\n\x1dUpdateGroupMemberAdminChanged\x12\x1f\n\x08group_id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1e\n\x07user_id\x18\x02 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1f\n\x08is_admin\x18\x03 \x01(\x08\x42\r\x8a\xea\x30\t\n\x07visible\"\xfa\x02\n\x12RequestCreateGroup\x12\x1a\n\x03rid\x18\x01 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12#\n\x08space_id\x18\t \x01(\x0b\x32\x11.dialog.UUIDValue\x12\x1b\n\x05title\x18\x02 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06hidden\x12\x31\n\x05users\x18\x03 \x03(\x0b\x32\x13.dialog.UserOutPeerB\r\x8a\xea\x30\t\n\x07visible\x12\x34\n\ngroup_type\x18\x06 \x01(\x0e\x32\x11.dialog.GroupTypeB\r\x8a\xea\x30\t\n\x07visible\x12=\n\x08username\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\r\x8a\xea\x30\t\n\x07visible\x12@\n\roptimizations\x18\x07 \x03(\x0e\x32\x1a.dialog.UpdateOptimizationB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\xb4\x01\n\x13ResponseCreateGroup\x12\x0b\n\x03seq\x18\x01 \x01(\x05\x12\r\n\x05state\x18\x02 \x01(\x0c\x12\x1c\n\x05group\x18\x03 \x01(\x0b\x32\r.dialog.Group\x12\x1b\n\x05users\x18\x04 \x03(\x0b\x32\x0c.dialog.User\x12\'\n\nuser_peers\x18\x05 \x03(\x0b\x32\x13.dialog.UserOutPeer:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"\xe9\x01\n\x15RequestEditGroupTitle\x12\x37\n\ngroup_peer\x18\x01 \x01(\x0b\x32\x14.dialog.GroupOutPeerB\r\x8a\xea\x30\t\n\x07visible\x12\x1a\n\x03rid\x18\x04 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1b\n\x05title\x18\x03 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06hidden\x12@\n\roptimizations\x18\x05 \x03(\x0e\x32\x1a.dialog.UpdateOptimizationB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\x8d\x01\n\x18RequestSetGroupShortname\x12\x31\n\x04peer\x18\x01 \x01(\x0b\x32\x14.dialog.GroupOutPeerB\r\x8a\xea\x30\t\n\x07visible\x12 \n\tshortname\x18\x02 \x01(\tB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\x89\x02\n\x16RequestEditGroupAvatar\x12\x37\n\ngroup_peer\x18\x01 \x01(\x0b\x32\x14.dialog.GroupOutPeerB\r\x8a\xea\x30\t\n\x07visible\x12\x1a\n\x03rid\x18\x04 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12:\n\rfile_location\x18\x03 \x01(\x0b\x32\x14.dialog.FileLocationB\r\x8a\xea\x30\t\n\x07\x63ompact\x12@\n\roptimizations\x18\x05 \x03(\x0e\x32\x1a.dialog.UpdateOptimizationB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\xa2\x01\n\x17ResponseEditGroupAvatar\x12\x1e\n\x06\x61vatar\x18\x01 \x01(\x0b\x32\x0e.dialog.Avatar\x12\x0b\n\x03seq\x18\x02 \x01(\x05\x12\r\n\x05state\x18\x03 \x01(\x0c\x12\x0c\n\x04\x64\x61te\x18\x04 \x01(\x03\x12\x1e\n\x03mid\x18\x05 \x01(\x0b\x32\x11.dialog.UUIDValue:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"\xcf\x01\n\x18RequestRemoveGroupAvatar\x12\x37\n\ngroup_peer\x18\x01 \x01(\x0b\x32\x14.dialog.GroupOutPeerB\r\x8a\xea\x30\t\n\x07visible\x12\x1a\n\x03rid\x18\x04 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12@\n\roptimizations\x18\x05 \x03(\x0e\x32\x1a.dialog.UpdateOptimizationB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\x87\x02\n\x15RequestEditGroupTopic\x12\x37\n\ngroup_peer\x18\x01 \x01(\x0b\x32\x14.dialog.GroupOutPeerB\r\x8a\xea\x30\t\n\x07visible\x12\x1a\n\x03rid\x18\x02 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12\x39\n\x05topic\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x0c\x8a\xea\x30\x08\n\x06hidden\x12@\n\roptimizations\x18\x04 \x03(\x0e\x32\x1a.dialog.UpdateOptimizationB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\x87\x02\n\x15RequestEditGroupAbout\x12\x37\n\ngroup_peer\x18\x01 \x01(\x0b\x32\x14.dialog.GroupOutPeerB\r\x8a\xea\x30\t\n\x07visible\x12\x1a\n\x03rid\x18\x02 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12\x39\n\x05\x61\x62out\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x0c\x8a\xea\x30\x08\n\x06hidden\x12@\n\roptimizations\x18\x05 \x03(\x0e\x32\x1a.dialog.UpdateOptimizationB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\xfa\x01\n\x11RequestInviteUser\x12\x37\n\ngroup_peer\x18\x01 \x01(\x0b\x32\x14.dialog.GroupOutPeerB\r\x8a\xea\x30\t\n\x07visible\x12\x1a\n\x03rid\x18\x04 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12\x30\n\x04user\x18\x03 \x01(\x0b\x32\x13.dialog.UserOutPeerB\r\x8a\xea\x30\t\n\x07visible\x12@\n\roptimizations\x18\x05 \x03(\x0e\x32\x1a.dialog.UpdateOptimizationB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\xc8\x01\n\x11RequestLeaveGroup\x12\x37\n\ngroup_peer\x18\x01 \x01(\x0b\x32\x14.dialog.GroupOutPeerB\r\x8a\xea\x30\t\n\x07visible\x12\x1a\n\x03rid\x18\x02 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12@\n\roptimizations\x18\x03 \x03(\x0e\x32\x1a.dialog.UpdateOptimizationB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\xf8\x01\n\x0fRequestKickUser\x12\x37\n\ngroup_peer\x18\x01 \x01(\x0b\x32\x14.dialog.GroupOutPeerB\r\x8a\xea\x30\t\n\x07visible\x12\x1a\n\x03rid\x18\x04 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12\x30\n\x04user\x18\x03 \x01(\x0b\x32\x13.dialog.UserOutPeerB\r\x8a\xea\x30\t\n\x07visible\x12@\n\roptimizations\x18\x05 \x03(\x0e\x32\x1a.dialog.UpdateOptimizationB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\xe6\x01\n\x14RequestMakeUserAdmin\x12\x37\n\ngroup_peer\x18\x01 \x01(\x0b\x32\x14.dialog.GroupOutPeerB\r\x8a\xea\x30\t\n\x07visible\x12\x35\n\tuser_peer\x18\x02 \x01(\x0b\x32\x13.dialog.UserOutPeerB\r\x8a\xea\x30\t\n\x07visible\x12@\n\x0bpermissions\x18\x03 \x03(\x0e\x32\x1c.dialog.GroupAdminPermissionB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"x\n\x15GroupMemberPermission\x12\x1e\n\x07user_id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12?\n\x0bpermissions\x18\x02 \x03(\x0e\x32\x1c.dialog.GroupAdminPermissionB\x0c\x8a\xea\x30\x08\n\x06hidden\"\x82\x01\n RequestGetGroupMemberPermissions\x12\x1f\n\x08group_id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1f\n\x08user_ids\x18\x02 \x03(\x05\x42\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"v\n!ResponseGetGroupMemberPermissions\x12\x32\n\x0bpermissions\x18\x01 \x03(\x0b\x32\x1d.dialog.GroupMemberPermission:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"\xa8\x01\n#UpdateGroupMemberPermissionsChanged\x12\x1f\n\x08group_id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1e\n\x07user_id\x18\x02 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12@\n\x0bpermissions\x18\x03 \x03(\x0e\x32\x1c.dialog.GroupAdminPermissionB\r\x8a\xea\x30\t\n\x07visible\"\x93\x01\n\x18RequestTransferOwnership\x12\x37\n\ngroup_peer\x18\x01 \x01(\x0b\x32\x14.dialog.GroupOutPeerB\r\x8a\xea\x30\t\n\x07visible\x12 \n\tnew_owner\x18\x02 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"?\n\x11ResponseInviteUrl\x12\x0b\n\x03url\x18\x01 \x01(\t:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"q\n\x18RequestGetGroupInviteUrl\x12\x37\n\ngroup_peer\x18\x01 \x01(\x0b\x32\x14.dialog.GroupOutPeerB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"<\n\x1cRequestGetGroupInviteUrlBase:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"K\n\x1dResponseGetGroupInviteUrlBase\x12\x0b\n\x03url\x18\x01 \x01(\t:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"o\n\x16RequestRevokeInviteUrl\x12\x37\n\ngroup_peer\x18\x01 \x01(\x0b\x32\x14.dialog.GroupOutPeerB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\x8f\x01\n\x10RequestJoinGroup\x12\x1c\n\x05token\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12?\n\roptimizations\x18\x02 \x03(\x0e\x32\x1a.dialog.UpdateOptimizationB\x0c\x8a\xea\x30\x08\n\x06hidden:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\xe0\x01\n\x11ResponseJoinGroup\x12\x1c\n\x05group\x18\x01 \x01(\x0b\x32\r.dialog.Group\x12\x1b\n\x05users\x18\x05 \x03(\x0b\x32\x0c.dialog.User\x12\'\n\nuser_peers\x18\x07 \x03(\x0b\x32\x13.dialog.UserOutPeer\x12\x1e\n\x03mid\x18\x08 \x01(\x0b\x32\x11.dialog.UUIDValue\x12\x0b\n\x03seq\x18\x02 \x01(\x05\x12\r\n\x05state\x18\x03 \x01(\x0c\x12\x0c\n\x04\x64\x61te\x18\x04 \x01(\x03:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"i\n\x16RequestJoinGroupByPeer\x12\x31\n\x04peer\x18\x01 \x01(\x0b\x32\x14.dialog.GroupOutPeerB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\xac\x01\n\x1cRequestMakeUserAdminObsolete\x12\x37\n\ngroup_peer\x18\x01 \x01(\x0b\x32\x14.dialog.GroupOutPeerB\r\x8a\xea\x30\t\n\x07visible\x12\x35\n\tuser_peer\x18\x02 \x01(\x0b\x32\x13.dialog.UserOutPeerB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"{\n\x1dResponseMakeUserAdminObsolete\x12\x1f\n\x07members\x18\x01 \x03(\x0b\x32\x0e.dialog.Member\x12\x0b\n\x03seq\x18\x02 \x01(\x05\x12\r\n\x05state\x18\x03 \x01(\x0c:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"\xb8\x01\n\x19UpdateGroupInviteObsolete\x12\x1f\n\x08group_id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1a\n\x03rid\x18\t \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1e\n\x03mid\x18\n \x01(\x0b\x32\x11.dialog.UUIDValue\x12!\n\ninvite_uid\x18\x05 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1b\n\x04\x64\x61te\x18\x08 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\"\xe9\x01\n\x1eUpdateGroupUserInvitedObsolete\x12\x1f\n\x08group_id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1a\n\x03rid\x18\x05 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12-\n\x03mid\x18\x06 \x01(\x0b\x32\x11.dialog.UUIDValueB\r\x8a\xea\x30\t\n\x07visible\x12\x1a\n\x03uid\x18\x02 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\"\n\x0binviter_uid\x18\x03 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1b\n\x04\x64\x61te\x18\x04 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\"\x98\x01\n\x1cUpdateGroupUserLeaveObsolete\x12\x1f\n\x08group_id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1e\n\x03mid\x18\x05 \x01(\x0b\x32\x11.dialog.UUIDValue\x12\x1a\n\x03uid\x18\x02 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1b\n\x04\x64\x61te\x18\x03 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\"\xba\x01\n\x1bUpdateGroupUserKickObsolete\x12\x1f\n\x08group_id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1e\n\x03mid\x18\x06 \x01(\x0b\x32\x11.dialog.UUIDValue\x12\x1a\n\x03uid\x18\x02 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12!\n\nkicker_uid\x18\x03 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1b\n\x04\x64\x61te\x18\x04 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\"s\n UpdateGroupMembersUpdateObsolete\x12\x1f\n\x08group_id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12.\n\x07members\x18\x02 \x03(\x0b\x32\x0e.dialog.MemberB\r\x8a\xea\x30\t\n\x07visible\"\xb8\x01\n\x1fUpdateGroupTitleChangedObsolete\x12\x1f\n\x08group_id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1e\n\x03mid\x18\x06 \x01(\x0b\x32\x11.dialog.UUIDValue\x12\x1a\n\x03uid\x18\x02 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1b\n\x05title\x18\x03 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06hidden\x12\x1b\n\x04\x64\x61te\x18\x04 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\"\xd2\x01\n\x1fUpdateGroupTopicChangedObsolete\x12\x1f\n\x08group_id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1a\n\x03rid\x18\x02 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1a\n\x03uid\x18\x03 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x39\n\x05topic\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x0c\x8a\xea\x30\x08\n\x06hidden\x12\x1b\n\x04\x64\x61te\x18\x05 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\"}\n\x1fUpdateGroupAboutChangedObsolete\x12\x1f\n\x08group_id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x39\n\x05\x61\x62out\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x0c\x8a\xea\x30\x08\n\x06hidden\"\xcb\x01\n UpdateGroupAvatarChangedObsolete\x12\x1f\n\x08group_id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1e\n\x03mid\x18\x06 \x01(\x0b\x32\x11.dialog.UUIDValue\x12\x1a\n\x03uid\x18\x02 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12-\n\x06\x61vatar\x18\x03 \x01(\x0b\x32\x0e.dialog.AvatarB\r\x8a\xea\x30\t\n\x07\x63ompact\x12\x1b\n\x04\x64\x61te\x18\x04 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\"|\n\x1bUpdateGroupShortnameChanged\x12\x1f\n\x08group_id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12 \n\tshortname\x18\x02 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12\x1a\n\x03uid\x18\x03 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible*N\n\tGroupType\x12\x15\n\x11GROUPTYPE_UNKNOWN\x10\x00\x12\x13\n\x0fGROUPTYPE_GROUP\x10\x01\x12\x15\n\x11GROUPTYPE_CHANNEL\x10\x02*\xb5\x03\n\x14GroupAdminPermission\x12 \n\x1cGROUPADMINPERMISSION_UNKNOWN\x10\x00\x12&\n\"GROUPADMINPERMISSION_EDITSHORTNAME\x10\x01\x12\x1f\n\x1bGROUPADMINPERMISSION_INVITE\x10\x02\x12\x1d\n\x19GROUPADMINPERMISSION_KICK\x10\x03\x12#\n\x1fGROUPADMINPERMISSION_UPDATEINFO\x10\x04\x12\'\n#GROUPADMINPERMISSION_SETPERMISSIONS\x10\x05\x12$\n GROUPADMINPERMISSION_EDITMESSAGE\x10\x06\x12&\n\"GROUPADMINPERMISSION_DELETEMESSAGE\x10\x07\x12,\n(GROUPADMINPERMISSION_GETINTEGRATIONTOKEN\x10\x08\x12$\n GROUPADMINPERMISSION_SENDMESSAGE\x10\t\x12#\n\x1fGROUPADMINPERMISSION_PINMESSAGE\x10\n2\xa1\x14\n\x06Groups\x12z\n\x0eLoadFullGroups\x12\x1d.dialog.RequestLoadFullGroups\x1a\x1e.dialog.ResponseLoadFullGroups\")\x82\xd3\xe4\x93\x02#\"\x1e/v1/grpc/Groups/LoadFullGroups:\x01*\x12n\n\x0bLoadMembers\x12\x1a.dialog.RequestLoadMembers\x1a\x1b.dialog.ResponseLoadMembers\"&\x82\xd3\xe4\x93\x02 \"\x1b/v1/grpc/Groups/LoadMembers:\x01*\x12n\n\x0b\x43reateGroup\x12\x1a.dialog.RequestCreateGroup\x1a\x1b.dialog.ResponseCreateGroup\"&\x82\xd3\xe4\x93\x02 \"\x1b/v1/grpc/Groups/CreateGroup:\x01*\x12v\n\x0e\x45\x64itGroupTitle\x12\x1d.dialog.RequestEditGroupTitle\x1a\x1a.dialog.ResponseSeqDateMid\")\x82\xd3\xe4\x93\x02#\"\x1e/v1/grpc/Groups/EditGroupTitle:\x01*\x12x\n\x11SetGroupShortname\x12 .dialog.RequestSetGroupShortname\x1a\x13.dialog.ResponseSeq\",\x82\xd3\xe4\x93\x02&\"!/v1/grpc/Groups/SetGroupShortname:\x01*\x12~\n\x0f\x45\x64itGroupAvatar\x12\x1e.dialog.RequestEditGroupAvatar\x1a\x1f.dialog.ResponseEditGroupAvatar\"*\x82\xd3\xe4\x93\x02$\"\x1f/v1/grpc/Groups/EditGroupAvatar:\x01*\x12\x7f\n\x11RemoveGroupAvatar\x12 .dialog.RequestRemoveGroupAvatar\x1a\x1a.dialog.ResponseSeqDateMid\",\x82\xd3\xe4\x93\x02&\"!/v1/grpc/Groups/RemoveGroupAvatar:\x01*\x12s\n\x0e\x45\x64itGroupTopic\x12\x1d.dialog.RequestEditGroupTopic\x1a\x17.dialog.ResponseSeqDate\")\x82\xd3\xe4\x93\x02#\"\x1e/v1/grpc/Groups/EditGroupTopic:\x01*\x12s\n\x0e\x45\x64itGroupAbout\x12\x1d.dialog.RequestEditGroupAbout\x1a\x17.dialog.ResponseSeqDate\")\x82\xd3\xe4\x93\x02#\"\x1e/v1/grpc/Groups/EditGroupAbout:\x01*\x12j\n\nInviteUser\x12\x19.dialog.RequestInviteUser\x1a\x1a.dialog.ResponseSeqDateMid\"%\x82\xd3\xe4\x93\x02\x1f\"\x1a/v1/grpc/Groups/InviteUser:\x01*\x12j\n\nLeaveGroup\x12\x19.dialog.RequestLeaveGroup\x1a\x1a.dialog.ResponseSeqDateMid\"%\x82\xd3\xe4\x93\x02\x1f\"\x1a/v1/grpc/Groups/LeaveGroup:\x01*\x12\x64\n\x08KickUser\x12\x17.dialog.RequestKickUser\x1a\x1a.dialog.ResponseSeqDateMid\"#\x82\xd3\xe4\x93\x02\x1d\"\x18/v1/grpc/Groups/KickUser:\x01*\x12p\n\rMakeUserAdmin\x12\x1c.dialog.RequestMakeUserAdmin\x1a\x17.dialog.ResponseSeqDate\"(\x82\xd3\xe4\x93\x02\"\"\x1d/v1/grpc/Groups/MakeUserAdmin:\x01*\x12\xa6\x01\n\x19GetGroupMemberPermissions\x12(.dialog.RequestGetGroupMemberPermissions\x1a).dialog.ResponseGetGroupMemberPermissions\"4\x82\xd3\xe4\x93\x02.\")/v1/grpc/Groups/GetGroupMemberPermissions:\x01*\x12|\n\x11TransferOwnership\x12 .dialog.RequestTransferOwnership\x1a\x17.dialog.ResponseSeqDate\",\x82\xd3\xe4\x93\x02&\"!/v1/grpc/Groups/TransferOwnership:\x01*\x12~\n\x11GetGroupInviteUrl\x12 .dialog.RequestGetGroupInviteUrl\x1a\x19.dialog.ResponseInviteUrl\",\x82\xd3\xe4\x93\x02&\"!/v1/grpc/Groups/GetGroupInviteUrl:\x01*\x12\x96\x01\n\x15GetGroupInviteUrlBase\x12$.dialog.RequestGetGroupInviteUrlBase\x1a%.dialog.ResponseGetGroupInviteUrlBase\"0\x82\xd3\xe4\x93\x02*\"%/v1/grpc/Groups/GetGroupInviteUrlBase:\x01*\x12x\n\x0fRevokeInviteUrl\x12\x1e.dialog.RequestRevokeInviteUrl\x1a\x19.dialog.ResponseInviteUrl\"*\x82\xd3\xe4\x93\x02$\"\x1f/v1/grpc/Groups/RevokeInviteUrl:\x01*\x12\x66\n\tJoinGroup\x12\x18.dialog.RequestJoinGroup\x1a\x19.dialog.ResponseJoinGroup\"$\x82\xd3\xe4\x93\x02\x1e\"\x19/v1/grpc/Groups/JoinGroup:\x01*\x12s\n\x0fJoinGroupByPeer\x12\x1e.dialog.RequestJoinGroupByPeer\x1a\x14.dialog.ResponseVoid\"*\x82\xd3\xe4\x93\x02$\"\x1f/v1/grpc/Groups/JoinGroupByPeer:\x01*\x12\x96\x01\n\x15MakeUserAdminObsolete\x12$.dialog.RequestMakeUserAdminObsolete\x1a%.dialog.ResponseMakeUserAdminObsolete\"0\x82\xd3\xe4\x93\x02*\"%/v1/grpc/Groups/MakeUserAdminObsolete:\x01*B\x19\xe2?\x16\n\x14im.dlg.grpc.servicesb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,definitions__pb2.DESCRIPTOR,miscellaneous__pb2.DESCRIPTOR,peers__pb2.DESCRIPTOR,media__and__files__pb2.DESCRIPTOR,users__pb2.DESCRIPTOR,scalapb_dot_scalapb__pb2.DESCRIPTOR,])

_GROUPTYPE = _descriptor.EnumDescriptor(
  name='GroupType',
  full_name='dialog.GroupType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GROUPTYPE_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GROUPTYPE_GROUP', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GROUPTYPE_CHANNEL', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=10674,
  serialized_end=10752,
)
_sym_db.RegisterEnumDescriptor(_GROUPTYPE)

GroupType = enum_type_wrapper.EnumTypeWrapper(_GROUPTYPE)
_GROUPADMINPERMISSION = _descriptor.EnumDescriptor(
  name='GroupAdminPermission',
  full_name='dialog.GroupAdminPermission',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GROUPADMINPERMISSION_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GROUPADMINPERMISSION_EDITSHORTNAME', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GROUPADMINPERMISSION_INVITE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GROUPADMINPERMISSION_KICK', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GROUPADMINPERMISSION_UPDATEINFO', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GROUPADMINPERMISSION_SETPERMISSIONS', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GROUPADMINPERMISSION_EDITMESSAGE', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GROUPADMINPERMISSION_DELETEMESSAGE', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GROUPADMINPERMISSION_GETINTEGRATIONTOKEN', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GROUPADMINPERMISSION_SENDMESSAGE', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GROUPADMINPERMISSION_PINMESSAGE', index=10, number=10,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=10755,
  serialized_end=11192,
)
_sym_db.RegisterEnumDescriptor(_GROUPADMINPERMISSION)

GroupAdminPermission = enum_type_wrapper.EnumTypeWrapper(_GROUPADMINPERMISSION)
GROUPTYPE_UNKNOWN = 0
GROUPTYPE_GROUP = 1
GROUPTYPE_CHANNEL = 2
GROUPADMINPERMISSION_UNKNOWN = 0
GROUPADMINPERMISSION_EDITSHORTNAME = 1
GROUPADMINPERMISSION_INVITE = 2
GROUPADMINPERMISSION_KICK = 3
GROUPADMINPERMISSION_UPDATEINFO = 4
GROUPADMINPERMISSION_SETPERMISSIONS = 5
GROUPADMINPERMISSION_EDITMESSAGE = 6
GROUPADMINPERMISSION_DELETEMESSAGE = 7
GROUPADMINPERMISSION_GETINTEGRATIONTOKEN = 8
GROUPADMINPERMISSION_SENDMESSAGE = 9
GROUPADMINPERMISSION_PINMESSAGE = 10



_MEMBER = _descriptor.Descriptor(
  name='Member',
  full_name='dialog.Member',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='dialog.Member.uid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inviter_uid', full_name='dialog.Member.inviter_uid', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date', full_name='dialog.Member.date', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_admin', full_name='dialog.Member.is_admin', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='permissions', full_name='dialog.Member.permissions', index=4,
      number=5, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=199,
  serialized_end=427,
)


_GROUP = _descriptor.Descriptor(
  name='Group',
  full_name='dialog.Group',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.Group.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='space_id', full_name='dialog.Group.space_id', index=1,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='access_hash', full_name='dialog.Group.access_hash', index=2,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006danger'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='title', full_name='dialog.Group.title', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='avatar', full_name='dialog.Group.avatar', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007compact'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='members_amount', full_name='dialog.Group.members_amount', index=5,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_member', full_name='dialog.Group.is_member', index=6,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_hidden', full_name='dialog.Group.is_hidden', index=7,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='group_type', full_name='dialog.Group.group_type', index=8,
      number=25, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='can_send_message', full_name='dialog.Group.can_send_message', index=9,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_admin', full_name='dialog.Group.is_admin', index=10,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='creator_uid', full_name='dialog.Group.creator_uid', index=11,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='members', full_name='dialog.Group.members', index=12,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007compact'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='create_date', full_name='dialog.Group.create_date', index=13,
      number=10, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='theme', full_name='dialog.Group.theme', index=14,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='about', full_name='dialog.Group.about', index=15,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shortname', full_name='dialog.Group.shortname', index=16,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=430,
  serialized_end=1290,
)


_GROUPFULL = _descriptor.Descriptor(
  name='GroupFull',
  full_name='dialog.GroupFull',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.GroupFull.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='create_date', full_name='dialog.GroupFull.create_date', index=1,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='owner_uid', full_name='dialog.GroupFull.owner_uid', index=2,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='members', full_name='dialog.GroupFull.members', index=3,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='theme', full_name='dialog.GroupFull.theme', index=4,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='about', full_name='dialog.GroupFull.about', index=5,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_async_members', full_name='dialog.GroupFull.is_async_members', index=6,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='can_view_members', full_name='dialog.GroupFull.can_view_members', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='can_invite_people', full_name='dialog.GroupFull.can_invite_people', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_shared_history', full_name='dialog.GroupFull.is_shared_history', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1293,
  serialized_end=1845,
)


_REQUESTLOADFULLGROUPS = _descriptor.Descriptor(
  name='RequestLoadFullGroups',
  full_name='dialog.RequestLoadFullGroups',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='groups', full_name='dialog.RequestLoadFullGroups.groups', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007compact'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1847,
  serialized_end=1953,
)


_RESPONSELOADFULLGROUPS = _descriptor.Descriptor(
  name='ResponseLoadFullGroups',
  full_name='dialog.ResponseLoadFullGroups',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='groups', full_name='dialog.ResponseLoadFullGroups.groups', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\032\n\030im.dlg.grpc.GrpcResponse'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1955,
  serialized_end=2045,
)


_REQUESTLOADMEMBERS = _descriptor.Descriptor(
  name='RequestLoadMembers',
  full_name='dialog.RequestLoadMembers',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group', full_name='dialog.RequestLoadMembers.group', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='dialog.RequestLoadMembers.limit', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next', full_name='dialog.RequestLoadMembers.next', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2048,
  serialized_end=2238,
)


_RESPONSELOADMEMBERS = _descriptor.Descriptor(
  name='ResponseLoadMembers',
  full_name='dialog.ResponseLoadMembers',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='members', full_name='dialog.ResponseLoadMembers.members', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next', full_name='dialog.ResponseLoadMembers.next', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\032\n\030im.dlg.grpc.GrpcResponse'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2241,
  serialized_end=2374,
)


_UPDATEGROUPTITLECHANGED = _descriptor.Descriptor(
  name='UpdateGroupTitleChanged',
  full_name='dialog.UpdateGroupTitleChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='dialog.UpdateGroupTitleChanged.group_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='title', full_name='dialog.UpdateGroupTitleChanged.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2376,
  serialized_end=2463,
)


_UPDATEGROUPAVATARCHANGED = _descriptor.Descriptor(
  name='UpdateGroupAvatarChanged',
  full_name='dialog.UpdateGroupAvatarChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='dialog.UpdateGroupAvatarChanged.group_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='avatar', full_name='dialog.UpdateGroupAvatarChanged.avatar', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2465,
  serialized_end=2571,
)


_UPDATEGROUPTOPICCHANGED = _descriptor.Descriptor(
  name='UpdateGroupTopicChanged',
  full_name='dialog.UpdateGroupTopicChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='dialog.UpdateGroupTopicChanged.group_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='topic', full_name='dialog.UpdateGroupTopicChanged.topic', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2573,
  serialized_end=2690,
)


_UPDATEGROUPABOUTCHANGED = _descriptor.Descriptor(
  name='UpdateGroupAboutChanged',
  full_name='dialog.UpdateGroupAboutChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='dialog.UpdateGroupAboutChanged.group_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='about', full_name='dialog.UpdateGroupAboutChanged.about', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2692,
  serialized_end=2809,
)


_UPDATEGROUPOWNERCHANGED = _descriptor.Descriptor(
  name='UpdateGroupOwnerChanged',
  full_name='dialog.UpdateGroupOwnerChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='dialog.UpdateGroupOwnerChanged.group_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='dialog.UpdateGroupOwnerChanged.user_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2811,
  serialized_end=2901,
)


_UPDATEGROUPHISTORYSHARED = _descriptor.Descriptor(
  name='UpdateGroupHistoryShared',
  full_name='dialog.UpdateGroupHistoryShared',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='dialog.UpdateGroupHistoryShared.group_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2903,
  serialized_end=2962,
)


_UPDATEGROUPCANSENDMESSAGESCHANGED = _descriptor.Descriptor(
  name='UpdateGroupCanSendMessagesChanged',
  full_name='dialog.UpdateGroupCanSendMessagesChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='dialog.UpdateGroupCanSendMessagesChanged.group_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='can_send_messages', full_name='dialog.UpdateGroupCanSendMessagesChanged.can_send_messages', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2964,
  serialized_end=3074,
)


_UPDATEGROUPCANVIEWMEMBERSCHANGED = _descriptor.Descriptor(
  name='UpdateGroupCanViewMembersChanged',
  full_name='dialog.UpdateGroupCanViewMembersChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='dialog.UpdateGroupCanViewMembersChanged.group_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='can_view_members', full_name='dialog.UpdateGroupCanViewMembersChanged.can_view_members', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3076,
  serialized_end=3184,
)


_UPDATEGROUPCANINVITEMEMBERSCHANGED = _descriptor.Descriptor(
  name='UpdateGroupCanInviteMembersChanged',
  full_name='dialog.UpdateGroupCanInviteMembersChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='dialog.UpdateGroupCanInviteMembersChanged.group_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='can_invite_members', full_name='dialog.UpdateGroupCanInviteMembersChanged.can_invite_members', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3186,
  serialized_end=3298,
)


_UPDATEGROUPMEMBERCHANGED = _descriptor.Descriptor(
  name='UpdateGroupMemberChanged',
  full_name='dialog.UpdateGroupMemberChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='dialog.UpdateGroupMemberChanged.group_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_member', full_name='dialog.UpdateGroupMemberChanged.is_member', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3300,
  serialized_end=3393,
)


_UPDATEGROUPMEMBERSBECAMEASYNC = _descriptor.Descriptor(
  name='UpdateGroupMembersBecameAsync',
  full_name='dialog.UpdateGroupMembersBecameAsync',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='dialog.UpdateGroupMembersBecameAsync.group_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3395,
  serialized_end=3459,
)


_UPDATEGROUPMEMBERSUPDATED = _descriptor.Descriptor(
  name='UpdateGroupMembersUpdated',
  full_name='dialog.UpdateGroupMembersUpdated',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='dialog.UpdateGroupMembersUpdated.group_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='members', full_name='dialog.UpdateGroupMembersUpdated.members', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3461,
  serialized_end=3569,
)


_UPDATEGROUPMEMBERDIFF = _descriptor.Descriptor(
  name='UpdateGroupMemberDiff',
  full_name='dialog.UpdateGroupMemberDiff',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='removed_users', full_name='dialog.UpdateGroupMemberDiff.removed_users', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='added_members', full_name='dialog.UpdateGroupMemberDiff.added_members', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='members_count', full_name='dialog.UpdateGroupMemberDiff.members_count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3572,
  serialized_end=3725,
)


_UPDATEGROUPMEMBERSCOUNTCHANGED = _descriptor.Descriptor(
  name='UpdateGroupMembersCountChanged',
  full_name='dialog.UpdateGroupMembersCountChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='dialog.UpdateGroupMembersCountChanged.group_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='members_count', full_name='dialog.UpdateGroupMembersCountChanged.members_count', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3727,
  serialized_end=3830,
)


_UPDATEGROUPMEMBERADMINCHANGED = _descriptor.Descriptor(
  name='UpdateGroupMemberAdminChanged',
  full_name='dialog.UpdateGroupMemberAdminChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='dialog.UpdateGroupMemberAdminChanged.group_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='dialog.UpdateGroupMemberAdminChanged.user_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_admin', full_name='dialog.UpdateGroupMemberAdminChanged.is_admin', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3833,
  serialized_end=3962,
)


_REQUESTCREATEGROUP = _descriptor.Descriptor(
  name='RequestCreateGroup',
  full_name='dialog.RequestCreateGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rid', full_name='dialog.RequestCreateGroup.rid', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='space_id', full_name='dialog.RequestCreateGroup.space_id', index=1,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='title', full_name='dialog.RequestCreateGroup.title', index=2,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='users', full_name='dialog.RequestCreateGroup.users', index=3,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='group_type', full_name='dialog.RequestCreateGroup.group_type', index=4,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='dialog.RequestCreateGroup.username', index=5,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='optimizations', full_name='dialog.RequestCreateGroup.optimizations', index=6,
      number=7, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3965,
  serialized_end=4343,
)


_RESPONSECREATEGROUP = _descriptor.Descriptor(
  name='ResponseCreateGroup',
  full_name='dialog.ResponseCreateGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='seq', full_name='dialog.ResponseCreateGroup.seq', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='dialog.ResponseCreateGroup.state', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='group', full_name='dialog.ResponseCreateGroup.group', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='users', full_name='dialog.ResponseCreateGroup.users', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_peers', full_name='dialog.ResponseCreateGroup.user_peers', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\032\n\030im.dlg.grpc.GrpcResponse'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4346,
  serialized_end=4526,
)


_REQUESTEDITGROUPTITLE = _descriptor.Descriptor(
  name='RequestEditGroupTitle',
  full_name='dialog.RequestEditGroupTitle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_peer', full_name='dialog.RequestEditGroupTitle.group_peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rid', full_name='dialog.RequestEditGroupTitle.rid', index=1,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='title', full_name='dialog.RequestEditGroupTitle.title', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='optimizations', full_name='dialog.RequestEditGroupTitle.optimizations', index=3,
      number=5, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4529,
  serialized_end=4762,
)


_REQUESTSETGROUPSHORTNAME = _descriptor.Descriptor(
  name='RequestSetGroupShortname',
  full_name='dialog.RequestSetGroupShortname',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.RequestSetGroupShortname.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shortname', full_name='dialog.RequestSetGroupShortname.shortname', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4765,
  serialized_end=4906,
)


_REQUESTEDITGROUPAVATAR = _descriptor.Descriptor(
  name='RequestEditGroupAvatar',
  full_name='dialog.RequestEditGroupAvatar',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_peer', full_name='dialog.RequestEditGroupAvatar.group_peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rid', full_name='dialog.RequestEditGroupAvatar.rid', index=1,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='file_location', full_name='dialog.RequestEditGroupAvatar.file_location', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007compact'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='optimizations', full_name='dialog.RequestEditGroupAvatar.optimizations', index=3,
      number=5, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4909,
  serialized_end=5174,
)


_RESPONSEEDITGROUPAVATAR = _descriptor.Descriptor(
  name='ResponseEditGroupAvatar',
  full_name='dialog.ResponseEditGroupAvatar',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='avatar', full_name='dialog.ResponseEditGroupAvatar.avatar', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seq', full_name='dialog.ResponseEditGroupAvatar.seq', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='dialog.ResponseEditGroupAvatar.state', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date', full_name='dialog.ResponseEditGroupAvatar.date', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mid', full_name='dialog.ResponseEditGroupAvatar.mid', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\032\n\030im.dlg.grpc.GrpcResponse'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5177,
  serialized_end=5339,
)


_REQUESTREMOVEGROUPAVATAR = _descriptor.Descriptor(
  name='RequestRemoveGroupAvatar',
  full_name='dialog.RequestRemoveGroupAvatar',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_peer', full_name='dialog.RequestRemoveGroupAvatar.group_peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rid', full_name='dialog.RequestRemoveGroupAvatar.rid', index=1,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='optimizations', full_name='dialog.RequestRemoveGroupAvatar.optimizations', index=2,
      number=5, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5342,
  serialized_end=5549,
)


_REQUESTEDITGROUPTOPIC = _descriptor.Descriptor(
  name='RequestEditGroupTopic',
  full_name='dialog.RequestEditGroupTopic',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_peer', full_name='dialog.RequestEditGroupTopic.group_peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rid', full_name='dialog.RequestEditGroupTopic.rid', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='topic', full_name='dialog.RequestEditGroupTopic.topic', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='optimizations', full_name='dialog.RequestEditGroupTopic.optimizations', index=3,
      number=4, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5552,
  serialized_end=5815,
)


_REQUESTEDITGROUPABOUT = _descriptor.Descriptor(
  name='RequestEditGroupAbout',
  full_name='dialog.RequestEditGroupAbout',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_peer', full_name='dialog.RequestEditGroupAbout.group_peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rid', full_name='dialog.RequestEditGroupAbout.rid', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='about', full_name='dialog.RequestEditGroupAbout.about', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='optimizations', full_name='dialog.RequestEditGroupAbout.optimizations', index=3,
      number=5, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5818,
  serialized_end=6081,
)


_REQUESTINVITEUSER = _descriptor.Descriptor(
  name='RequestInviteUser',
  full_name='dialog.RequestInviteUser',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_peer', full_name='dialog.RequestInviteUser.group_peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rid', full_name='dialog.RequestInviteUser.rid', index=1,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user', full_name='dialog.RequestInviteUser.user', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='optimizations', full_name='dialog.RequestInviteUser.optimizations', index=3,
      number=5, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6084,
  serialized_end=6334,
)


_REQUESTLEAVEGROUP = _descriptor.Descriptor(
  name='RequestLeaveGroup',
  full_name='dialog.RequestLeaveGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_peer', full_name='dialog.RequestLeaveGroup.group_peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rid', full_name='dialog.RequestLeaveGroup.rid', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='optimizations', full_name='dialog.RequestLeaveGroup.optimizations', index=2,
      number=3, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6337,
  serialized_end=6537,
)


_REQUESTKICKUSER = _descriptor.Descriptor(
  name='RequestKickUser',
  full_name='dialog.RequestKickUser',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_peer', full_name='dialog.RequestKickUser.group_peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rid', full_name='dialog.RequestKickUser.rid', index=1,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user', full_name='dialog.RequestKickUser.user', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='optimizations', full_name='dialog.RequestKickUser.optimizations', index=3,
      number=5, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6540,
  serialized_end=6788,
)


_REQUESTMAKEUSERADMIN = _descriptor.Descriptor(
  name='RequestMakeUserAdmin',
  full_name='dialog.RequestMakeUserAdmin',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_peer', full_name='dialog.RequestMakeUserAdmin.group_peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_peer', full_name='dialog.RequestMakeUserAdmin.user_peer', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='permissions', full_name='dialog.RequestMakeUserAdmin.permissions', index=2,
      number=3, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6791,
  serialized_end=7021,
)


_GROUPMEMBERPERMISSION = _descriptor.Descriptor(
  name='GroupMemberPermission',
  full_name='dialog.GroupMemberPermission',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='dialog.GroupMemberPermission.user_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='permissions', full_name='dialog.GroupMemberPermission.permissions', index=1,
      number=2, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7023,
  serialized_end=7143,
)


_REQUESTGETGROUPMEMBERPERMISSIONS = _descriptor.Descriptor(
  name='RequestGetGroupMemberPermissions',
  full_name='dialog.RequestGetGroupMemberPermissions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='dialog.RequestGetGroupMemberPermissions.group_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_ids', full_name='dialog.RequestGetGroupMemberPermissions.user_ids', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7146,
  serialized_end=7276,
)


_RESPONSEGETGROUPMEMBERPERMISSIONS = _descriptor.Descriptor(
  name='ResponseGetGroupMemberPermissions',
  full_name='dialog.ResponseGetGroupMemberPermissions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='permissions', full_name='dialog.ResponseGetGroupMemberPermissions.permissions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\032\n\030im.dlg.grpc.GrpcResponse'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7278,
  serialized_end=7396,
)


_UPDATEGROUPMEMBERPERMISSIONSCHANGED = _descriptor.Descriptor(
  name='UpdateGroupMemberPermissionsChanged',
  full_name='dialog.UpdateGroupMemberPermissionsChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='dialog.UpdateGroupMemberPermissionsChanged.group_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='dialog.UpdateGroupMemberPermissionsChanged.user_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='permissions', full_name='dialog.UpdateGroupMemberPermissionsChanged.permissions', index=2,
      number=3, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7399,
  serialized_end=7567,
)


_REQUESTTRANSFEROWNERSHIP = _descriptor.Descriptor(
  name='RequestTransferOwnership',
  full_name='dialog.RequestTransferOwnership',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_peer', full_name='dialog.RequestTransferOwnership.group_peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_owner', full_name='dialog.RequestTransferOwnership.new_owner', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7570,
  serialized_end=7717,
)


_RESPONSEINVITEURL = _descriptor.Descriptor(
  name='ResponseInviteUrl',
  full_name='dialog.ResponseInviteUrl',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='url', full_name='dialog.ResponseInviteUrl.url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\032\n\030im.dlg.grpc.GrpcResponse'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7719,
  serialized_end=7782,
)


_REQUESTGETGROUPINVITEURL = _descriptor.Descriptor(
  name='RequestGetGroupInviteUrl',
  full_name='dialog.RequestGetGroupInviteUrl',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_peer', full_name='dialog.RequestGetGroupInviteUrl.group_peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7784,
  serialized_end=7897,
)


_REQUESTGETGROUPINVITEURLBASE = _descriptor.Descriptor(
  name='RequestGetGroupInviteUrlBase',
  full_name='dialog.RequestGetGroupInviteUrlBase',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7899,
  serialized_end=7959,
)


_RESPONSEGETGROUPINVITEURLBASE = _descriptor.Descriptor(
  name='ResponseGetGroupInviteUrlBase',
  full_name='dialog.ResponseGetGroupInviteUrlBase',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='url', full_name='dialog.ResponseGetGroupInviteUrlBase.url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\032\n\030im.dlg.grpc.GrpcResponse'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7961,
  serialized_end=8036,
)


_REQUESTREVOKEINVITEURL = _descriptor.Descriptor(
  name='RequestRevokeInviteUrl',
  full_name='dialog.RequestRevokeInviteUrl',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_peer', full_name='dialog.RequestRevokeInviteUrl.group_peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8038,
  serialized_end=8149,
)


_REQUESTJOINGROUP = _descriptor.Descriptor(
  name='RequestJoinGroup',
  full_name='dialog.RequestJoinGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='dialog.RequestJoinGroup.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='optimizations', full_name='dialog.RequestJoinGroup.optimizations', index=1,
      number=2, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8152,
  serialized_end=8295,
)


_RESPONSEJOINGROUP = _descriptor.Descriptor(
  name='ResponseJoinGroup',
  full_name='dialog.ResponseJoinGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group', full_name='dialog.ResponseJoinGroup.group', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='users', full_name='dialog.ResponseJoinGroup.users', index=1,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_peers', full_name='dialog.ResponseJoinGroup.user_peers', index=2,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mid', full_name='dialog.ResponseJoinGroup.mid', index=3,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seq', full_name='dialog.ResponseJoinGroup.seq', index=4,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='dialog.ResponseJoinGroup.state', index=5,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date', full_name='dialog.ResponseJoinGroup.date', index=6,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\032\n\030im.dlg.grpc.GrpcResponse'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8298,
  serialized_end=8522,
)


_REQUESTJOINGROUPBYPEER = _descriptor.Descriptor(
  name='RequestJoinGroupByPeer',
  full_name='dialog.RequestJoinGroupByPeer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.RequestJoinGroupByPeer.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8524,
  serialized_end=8629,
)


_REQUESTMAKEUSERADMINOBSOLETE = _descriptor.Descriptor(
  name='RequestMakeUserAdminObsolete',
  full_name='dialog.RequestMakeUserAdminObsolete',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_peer', full_name='dialog.RequestMakeUserAdminObsolete.group_peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_peer', full_name='dialog.RequestMakeUserAdminObsolete.user_peer', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8632,
  serialized_end=8804,
)


_RESPONSEMAKEUSERADMINOBSOLETE = _descriptor.Descriptor(
  name='ResponseMakeUserAdminObsolete',
  full_name='dialog.ResponseMakeUserAdminObsolete',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='members', full_name='dialog.ResponseMakeUserAdminObsolete.members', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seq', full_name='dialog.ResponseMakeUserAdminObsolete.seq', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='dialog.ResponseMakeUserAdminObsolete.state', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\032\n\030im.dlg.grpc.GrpcResponse'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8806,
  serialized_end=8929,
)


_UPDATEGROUPINVITEOBSOLETE = _descriptor.Descriptor(
  name='UpdateGroupInviteObsolete',
  full_name='dialog.UpdateGroupInviteObsolete',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='dialog.UpdateGroupInviteObsolete.group_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rid', full_name='dialog.UpdateGroupInviteObsolete.rid', index=1,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mid', full_name='dialog.UpdateGroupInviteObsolete.mid', index=2,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='invite_uid', full_name='dialog.UpdateGroupInviteObsolete.invite_uid', index=3,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date', full_name='dialog.UpdateGroupInviteObsolete.date', index=4,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8932,
  serialized_end=9116,
)


_UPDATEGROUPUSERINVITEDOBSOLETE = _descriptor.Descriptor(
  name='UpdateGroupUserInvitedObsolete',
  full_name='dialog.UpdateGroupUserInvitedObsolete',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='dialog.UpdateGroupUserInvitedObsolete.group_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rid', full_name='dialog.UpdateGroupUserInvitedObsolete.rid', index=1,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mid', full_name='dialog.UpdateGroupUserInvitedObsolete.mid', index=2,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uid', full_name='dialog.UpdateGroupUserInvitedObsolete.uid', index=3,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inviter_uid', full_name='dialog.UpdateGroupUserInvitedObsolete.inviter_uid', index=4,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date', full_name='dialog.UpdateGroupUserInvitedObsolete.date', index=5,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9119,
  serialized_end=9352,
)


_UPDATEGROUPUSERLEAVEOBSOLETE = _descriptor.Descriptor(
  name='UpdateGroupUserLeaveObsolete',
  full_name='dialog.UpdateGroupUserLeaveObsolete',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='dialog.UpdateGroupUserLeaveObsolete.group_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mid', full_name='dialog.UpdateGroupUserLeaveObsolete.mid', index=1,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uid', full_name='dialog.UpdateGroupUserLeaveObsolete.uid', index=2,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date', full_name='dialog.UpdateGroupUserLeaveObsolete.date', index=3,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9355,
  serialized_end=9507,
)


_UPDATEGROUPUSERKICKOBSOLETE = _descriptor.Descriptor(
  name='UpdateGroupUserKickObsolete',
  full_name='dialog.UpdateGroupUserKickObsolete',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='dialog.UpdateGroupUserKickObsolete.group_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mid', full_name='dialog.UpdateGroupUserKickObsolete.mid', index=1,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uid', full_name='dialog.UpdateGroupUserKickObsolete.uid', index=2,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='kicker_uid', full_name='dialog.UpdateGroupUserKickObsolete.kicker_uid', index=3,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date', full_name='dialog.UpdateGroupUserKickObsolete.date', index=4,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9510,
  serialized_end=9696,
)


_UPDATEGROUPMEMBERSUPDATEOBSOLETE = _descriptor.Descriptor(
  name='UpdateGroupMembersUpdateObsolete',
  full_name='dialog.UpdateGroupMembersUpdateObsolete',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='dialog.UpdateGroupMembersUpdateObsolete.group_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='members', full_name='dialog.UpdateGroupMembersUpdateObsolete.members', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9698,
  serialized_end=9813,
)


_UPDATEGROUPTITLECHANGEDOBSOLETE = _descriptor.Descriptor(
  name='UpdateGroupTitleChangedObsolete',
  full_name='dialog.UpdateGroupTitleChangedObsolete',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='dialog.UpdateGroupTitleChangedObsolete.group_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mid', full_name='dialog.UpdateGroupTitleChangedObsolete.mid', index=1,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uid', full_name='dialog.UpdateGroupTitleChangedObsolete.uid', index=2,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='title', full_name='dialog.UpdateGroupTitleChangedObsolete.title', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date', full_name='dialog.UpdateGroupTitleChangedObsolete.date', index=4,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9816,
  serialized_end=10000,
)


_UPDATEGROUPTOPICCHANGEDOBSOLETE = _descriptor.Descriptor(
  name='UpdateGroupTopicChangedObsolete',
  full_name='dialog.UpdateGroupTopicChangedObsolete',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='dialog.UpdateGroupTopicChangedObsolete.group_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rid', full_name='dialog.UpdateGroupTopicChangedObsolete.rid', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uid', full_name='dialog.UpdateGroupTopicChangedObsolete.uid', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='topic', full_name='dialog.UpdateGroupTopicChangedObsolete.topic', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date', full_name='dialog.UpdateGroupTopicChangedObsolete.date', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10003,
  serialized_end=10213,
)


_UPDATEGROUPABOUTCHANGEDOBSOLETE = _descriptor.Descriptor(
  name='UpdateGroupAboutChangedObsolete',
  full_name='dialog.UpdateGroupAboutChangedObsolete',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='dialog.UpdateGroupAboutChangedObsolete.group_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='about', full_name='dialog.UpdateGroupAboutChangedObsolete.about', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10215,
  serialized_end=10340,
)


_UPDATEGROUPAVATARCHANGEDOBSOLETE = _descriptor.Descriptor(
  name='UpdateGroupAvatarChangedObsolete',
  full_name='dialog.UpdateGroupAvatarChangedObsolete',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='dialog.UpdateGroupAvatarChangedObsolete.group_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mid', full_name='dialog.UpdateGroupAvatarChangedObsolete.mid', index=1,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uid', full_name='dialog.UpdateGroupAvatarChangedObsolete.uid', index=2,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='avatar', full_name='dialog.UpdateGroupAvatarChangedObsolete.avatar', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007compact'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date', full_name='dialog.UpdateGroupAvatarChangedObsolete.date', index=4,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10343,
  serialized_end=10546,
)


_UPDATEGROUPSHORTNAMECHANGED = _descriptor.Descriptor(
  name='UpdateGroupShortnameChanged',
  full_name='dialog.UpdateGroupShortnameChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='dialog.UpdateGroupShortnameChanged.group_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shortname', full_name='dialog.UpdateGroupShortnameChanged.shortname', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uid', full_name='dialog.UpdateGroupShortnameChanged.uid', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10548,
  serialized_end=10672,
)

_MEMBER.fields_by_name['is_admin'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_MEMBER.fields_by_name['permissions'].enum_type = _GROUPADMINPERMISSION
_GROUP.fields_by_name['space_id'].message_type = definitions__pb2._UUIDVALUE
_GROUP.fields_by_name['avatar'].message_type = media__and__files__pb2._AVATAR
_GROUP.fields_by_name['members_amount'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_GROUP.fields_by_name['is_member'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_GROUP.fields_by_name['is_hidden'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_GROUP.fields_by_name['group_type'].enum_type = _GROUPTYPE
_GROUP.fields_by_name['can_send_message'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_GROUP.fields_by_name['is_admin'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_GROUP.fields_by_name['members'].message_type = _MEMBER
_GROUP.fields_by_name['theme'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GROUP.fields_by_name['about'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GROUP.fields_by_name['shortname'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GROUPFULL.fields_by_name['members'].message_type = _MEMBER
_GROUPFULL.fields_by_name['theme'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GROUPFULL.fields_by_name['about'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GROUPFULL.fields_by_name['is_async_members'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_GROUPFULL.fields_by_name['can_view_members'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_GROUPFULL.fields_by_name['can_invite_people'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_GROUPFULL.fields_by_name['is_shared_history'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_REQUESTLOADFULLGROUPS.fields_by_name['groups'].message_type = peers__pb2._GROUPOUTPEER
_RESPONSELOADFULLGROUPS.fields_by_name['groups'].message_type = _GROUPFULL
_REQUESTLOADMEMBERS.fields_by_name['group'].message_type = peers__pb2._GROUPOUTPEER
_REQUESTLOADMEMBERS.fields_by_name['next'].message_type = google_dot_protobuf_dot_wrappers__pb2._BYTESVALUE
_RESPONSELOADMEMBERS.fields_by_name['members'].message_type = peers__pb2._USEROUTPEER
_RESPONSELOADMEMBERS.fields_by_name['next'].message_type = google_dot_protobuf_dot_wrappers__pb2._BYTESVALUE
_UPDATEGROUPAVATARCHANGED.fields_by_name['avatar'].message_type = media__and__files__pb2._AVATAR
_UPDATEGROUPTOPICCHANGED.fields_by_name['topic'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_UPDATEGROUPABOUTCHANGED.fields_by_name['about'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_UPDATEGROUPMEMBERSUPDATED.fields_by_name['members'].message_type = _MEMBER
_UPDATEGROUPMEMBERDIFF.fields_by_name['added_members'].message_type = _MEMBER
_REQUESTCREATEGROUP.fields_by_name['space_id'].message_type = definitions__pb2._UUIDVALUE
_REQUESTCREATEGROUP.fields_by_name['users'].message_type = peers__pb2._USEROUTPEER
_REQUESTCREATEGROUP.fields_by_name['group_type'].enum_type = _GROUPTYPE
_REQUESTCREATEGROUP.fields_by_name['username'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_REQUESTCREATEGROUP.fields_by_name['optimizations'].enum_type = miscellaneous__pb2._UPDATEOPTIMIZATION
_RESPONSECREATEGROUP.fields_by_name['group'].message_type = _GROUP
_RESPONSECREATEGROUP.fields_by_name['users'].message_type = users__pb2._USER
_RESPONSECREATEGROUP.fields_by_name['user_peers'].message_type = peers__pb2._USEROUTPEER
_REQUESTEDITGROUPTITLE.fields_by_name['group_peer'].message_type = peers__pb2._GROUPOUTPEER
_REQUESTEDITGROUPTITLE.fields_by_name['optimizations'].enum_type = miscellaneous__pb2._UPDATEOPTIMIZATION
_REQUESTSETGROUPSHORTNAME.fields_by_name['peer'].message_type = peers__pb2._GROUPOUTPEER
_REQUESTEDITGROUPAVATAR.fields_by_name['group_peer'].message_type = peers__pb2._GROUPOUTPEER
_REQUESTEDITGROUPAVATAR.fields_by_name['file_location'].message_type = media__and__files__pb2._FILELOCATION
_REQUESTEDITGROUPAVATAR.fields_by_name['optimizations'].enum_type = miscellaneous__pb2._UPDATEOPTIMIZATION
_RESPONSEEDITGROUPAVATAR.fields_by_name['avatar'].message_type = media__and__files__pb2._AVATAR
_RESPONSEEDITGROUPAVATAR.fields_by_name['mid'].message_type = definitions__pb2._UUIDVALUE
_REQUESTREMOVEGROUPAVATAR.fields_by_name['group_peer'].message_type = peers__pb2._GROUPOUTPEER
_REQUESTREMOVEGROUPAVATAR.fields_by_name['optimizations'].enum_type = miscellaneous__pb2._UPDATEOPTIMIZATION
_REQUESTEDITGROUPTOPIC.fields_by_name['group_peer'].message_type = peers__pb2._GROUPOUTPEER
_REQUESTEDITGROUPTOPIC.fields_by_name['topic'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_REQUESTEDITGROUPTOPIC.fields_by_name['optimizations'].enum_type = miscellaneous__pb2._UPDATEOPTIMIZATION
_REQUESTEDITGROUPABOUT.fields_by_name['group_peer'].message_type = peers__pb2._GROUPOUTPEER
_REQUESTEDITGROUPABOUT.fields_by_name['about'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_REQUESTEDITGROUPABOUT.fields_by_name['optimizations'].enum_type = miscellaneous__pb2._UPDATEOPTIMIZATION
_REQUESTINVITEUSER.fields_by_name['group_peer'].message_type = peers__pb2._GROUPOUTPEER
_REQUESTINVITEUSER.fields_by_name['user'].message_type = peers__pb2._USEROUTPEER
_REQUESTINVITEUSER.fields_by_name['optimizations'].enum_type = miscellaneous__pb2._UPDATEOPTIMIZATION
_REQUESTLEAVEGROUP.fields_by_name['group_peer'].message_type = peers__pb2._GROUPOUTPEER
_REQUESTLEAVEGROUP.fields_by_name['optimizations'].enum_type = miscellaneous__pb2._UPDATEOPTIMIZATION
_REQUESTKICKUSER.fields_by_name['group_peer'].message_type = peers__pb2._GROUPOUTPEER
_REQUESTKICKUSER.fields_by_name['user'].message_type = peers__pb2._USEROUTPEER
_REQUESTKICKUSER.fields_by_name['optimizations'].enum_type = miscellaneous__pb2._UPDATEOPTIMIZATION
_REQUESTMAKEUSERADMIN.fields_by_name['group_peer'].message_type = peers__pb2._GROUPOUTPEER
_REQUESTMAKEUSERADMIN.fields_by_name['user_peer'].message_type = peers__pb2._USEROUTPEER
_REQUESTMAKEUSERADMIN.fields_by_name['permissions'].enum_type = _GROUPADMINPERMISSION
_GROUPMEMBERPERMISSION.fields_by_name['permissions'].enum_type = _GROUPADMINPERMISSION
_RESPONSEGETGROUPMEMBERPERMISSIONS.fields_by_name['permissions'].message_type = _GROUPMEMBERPERMISSION
_UPDATEGROUPMEMBERPERMISSIONSCHANGED.fields_by_name['permissions'].enum_type = _GROUPADMINPERMISSION
_REQUESTTRANSFEROWNERSHIP.fields_by_name['group_peer'].message_type = peers__pb2._GROUPOUTPEER
_REQUESTGETGROUPINVITEURL.fields_by_name['group_peer'].message_type = peers__pb2._GROUPOUTPEER
_REQUESTREVOKEINVITEURL.fields_by_name['group_peer'].message_type = peers__pb2._GROUPOUTPEER
_REQUESTJOINGROUP.fields_by_name['optimizations'].enum_type = miscellaneous__pb2._UPDATEOPTIMIZATION
_RESPONSEJOINGROUP.fields_by_name['group'].message_type = _GROUP
_RESPONSEJOINGROUP.fields_by_name['users'].message_type = users__pb2._USER
_RESPONSEJOINGROUP.fields_by_name['user_peers'].message_type = peers__pb2._USEROUTPEER
_RESPONSEJOINGROUP.fields_by_name['mid'].message_type = definitions__pb2._UUIDVALUE
_REQUESTJOINGROUPBYPEER.fields_by_name['peer'].message_type = peers__pb2._GROUPOUTPEER
_REQUESTMAKEUSERADMINOBSOLETE.fields_by_name['group_peer'].message_type = peers__pb2._GROUPOUTPEER
_REQUESTMAKEUSERADMINOBSOLETE.fields_by_name['user_peer'].message_type = peers__pb2._USEROUTPEER
_RESPONSEMAKEUSERADMINOBSOLETE.fields_by_name['members'].message_type = _MEMBER
_UPDATEGROUPINVITEOBSOLETE.fields_by_name['mid'].message_type = definitions__pb2._UUIDVALUE
_UPDATEGROUPUSERINVITEDOBSOLETE.fields_by_name['mid'].message_type = definitions__pb2._UUIDVALUE
_UPDATEGROUPUSERLEAVEOBSOLETE.fields_by_name['mid'].message_type = definitions__pb2._UUIDVALUE
_UPDATEGROUPUSERKICKOBSOLETE.fields_by_name['mid'].message_type = definitions__pb2._UUIDVALUE
_UPDATEGROUPMEMBERSUPDATEOBSOLETE.fields_by_name['members'].message_type = _MEMBER
_UPDATEGROUPTITLECHANGEDOBSOLETE.fields_by_name['mid'].message_type = definitions__pb2._UUIDVALUE
_UPDATEGROUPTOPICCHANGEDOBSOLETE.fields_by_name['topic'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_UPDATEGROUPABOUTCHANGEDOBSOLETE.fields_by_name['about'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_UPDATEGROUPAVATARCHANGEDOBSOLETE.fields_by_name['mid'].message_type = definitions__pb2._UUIDVALUE
_UPDATEGROUPAVATARCHANGEDOBSOLETE.fields_by_name['avatar'].message_type = media__and__files__pb2._AVATAR
DESCRIPTOR.message_types_by_name['Member'] = _MEMBER
DESCRIPTOR.message_types_by_name['Group'] = _GROUP
DESCRIPTOR.message_types_by_name['GroupFull'] = _GROUPFULL
DESCRIPTOR.message_types_by_name['RequestLoadFullGroups'] = _REQUESTLOADFULLGROUPS
DESCRIPTOR.message_types_by_name['ResponseLoadFullGroups'] = _RESPONSELOADFULLGROUPS
DESCRIPTOR.message_types_by_name['RequestLoadMembers'] = _REQUESTLOADMEMBERS
DESCRIPTOR.message_types_by_name['ResponseLoadMembers'] = _RESPONSELOADMEMBERS
DESCRIPTOR.message_types_by_name['UpdateGroupTitleChanged'] = _UPDATEGROUPTITLECHANGED
DESCRIPTOR.message_types_by_name['UpdateGroupAvatarChanged'] = _UPDATEGROUPAVATARCHANGED
DESCRIPTOR.message_types_by_name['UpdateGroupTopicChanged'] = _UPDATEGROUPTOPICCHANGED
DESCRIPTOR.message_types_by_name['UpdateGroupAboutChanged'] = _UPDATEGROUPABOUTCHANGED
DESCRIPTOR.message_types_by_name['UpdateGroupOwnerChanged'] = _UPDATEGROUPOWNERCHANGED
DESCRIPTOR.message_types_by_name['UpdateGroupHistoryShared'] = _UPDATEGROUPHISTORYSHARED
DESCRIPTOR.message_types_by_name['UpdateGroupCanSendMessagesChanged'] = _UPDATEGROUPCANSENDMESSAGESCHANGED
DESCRIPTOR.message_types_by_name['UpdateGroupCanViewMembersChanged'] = _UPDATEGROUPCANVIEWMEMBERSCHANGED
DESCRIPTOR.message_types_by_name['UpdateGroupCanInviteMembersChanged'] = _UPDATEGROUPCANINVITEMEMBERSCHANGED
DESCRIPTOR.message_types_by_name['UpdateGroupMemberChanged'] = _UPDATEGROUPMEMBERCHANGED
DESCRIPTOR.message_types_by_name['UpdateGroupMembersBecameAsync'] = _UPDATEGROUPMEMBERSBECAMEASYNC
DESCRIPTOR.message_types_by_name['UpdateGroupMembersUpdated'] = _UPDATEGROUPMEMBERSUPDATED
DESCRIPTOR.message_types_by_name['UpdateGroupMemberDiff'] = _UPDATEGROUPMEMBERDIFF
DESCRIPTOR.message_types_by_name['UpdateGroupMembersCountChanged'] = _UPDATEGROUPMEMBERSCOUNTCHANGED
DESCRIPTOR.message_types_by_name['UpdateGroupMemberAdminChanged'] = _UPDATEGROUPMEMBERADMINCHANGED
DESCRIPTOR.message_types_by_name['RequestCreateGroup'] = _REQUESTCREATEGROUP
DESCRIPTOR.message_types_by_name['ResponseCreateGroup'] = _RESPONSECREATEGROUP
DESCRIPTOR.message_types_by_name['RequestEditGroupTitle'] = _REQUESTEDITGROUPTITLE
DESCRIPTOR.message_types_by_name['RequestSetGroupShortname'] = _REQUESTSETGROUPSHORTNAME
DESCRIPTOR.message_types_by_name['RequestEditGroupAvatar'] = _REQUESTEDITGROUPAVATAR
DESCRIPTOR.message_types_by_name['ResponseEditGroupAvatar'] = _RESPONSEEDITGROUPAVATAR
DESCRIPTOR.message_types_by_name['RequestRemoveGroupAvatar'] = _REQUESTREMOVEGROUPAVATAR
DESCRIPTOR.message_types_by_name['RequestEditGroupTopic'] = _REQUESTEDITGROUPTOPIC
DESCRIPTOR.message_types_by_name['RequestEditGroupAbout'] = _REQUESTEDITGROUPABOUT
DESCRIPTOR.message_types_by_name['RequestInviteUser'] = _REQUESTINVITEUSER
DESCRIPTOR.message_types_by_name['RequestLeaveGroup'] = _REQUESTLEAVEGROUP
DESCRIPTOR.message_types_by_name['RequestKickUser'] = _REQUESTKICKUSER
DESCRIPTOR.message_types_by_name['RequestMakeUserAdmin'] = _REQUESTMAKEUSERADMIN
DESCRIPTOR.message_types_by_name['GroupMemberPermission'] = _GROUPMEMBERPERMISSION
DESCRIPTOR.message_types_by_name['RequestGetGroupMemberPermissions'] = _REQUESTGETGROUPMEMBERPERMISSIONS
DESCRIPTOR.message_types_by_name['ResponseGetGroupMemberPermissions'] = _RESPONSEGETGROUPMEMBERPERMISSIONS
DESCRIPTOR.message_types_by_name['UpdateGroupMemberPermissionsChanged'] = _UPDATEGROUPMEMBERPERMISSIONSCHANGED
DESCRIPTOR.message_types_by_name['RequestTransferOwnership'] = _REQUESTTRANSFEROWNERSHIP
DESCRIPTOR.message_types_by_name['ResponseInviteUrl'] = _RESPONSEINVITEURL
DESCRIPTOR.message_types_by_name['RequestGetGroupInviteUrl'] = _REQUESTGETGROUPINVITEURL
DESCRIPTOR.message_types_by_name['RequestGetGroupInviteUrlBase'] = _REQUESTGETGROUPINVITEURLBASE
DESCRIPTOR.message_types_by_name['ResponseGetGroupInviteUrlBase'] = _RESPONSEGETGROUPINVITEURLBASE
DESCRIPTOR.message_types_by_name['RequestRevokeInviteUrl'] = _REQUESTREVOKEINVITEURL
DESCRIPTOR.message_types_by_name['RequestJoinGroup'] = _REQUESTJOINGROUP
DESCRIPTOR.message_types_by_name['ResponseJoinGroup'] = _RESPONSEJOINGROUP
DESCRIPTOR.message_types_by_name['RequestJoinGroupByPeer'] = _REQUESTJOINGROUPBYPEER
DESCRIPTOR.message_types_by_name['RequestMakeUserAdminObsolete'] = _REQUESTMAKEUSERADMINOBSOLETE
DESCRIPTOR.message_types_by_name['ResponseMakeUserAdminObsolete'] = _RESPONSEMAKEUSERADMINOBSOLETE
DESCRIPTOR.message_types_by_name['UpdateGroupInviteObsolete'] = _UPDATEGROUPINVITEOBSOLETE
DESCRIPTOR.message_types_by_name['UpdateGroupUserInvitedObsolete'] = _UPDATEGROUPUSERINVITEDOBSOLETE
DESCRIPTOR.message_types_by_name['UpdateGroupUserLeaveObsolete'] = _UPDATEGROUPUSERLEAVEOBSOLETE
DESCRIPTOR.message_types_by_name['UpdateGroupUserKickObsolete'] = _UPDATEGROUPUSERKICKOBSOLETE
DESCRIPTOR.message_types_by_name['UpdateGroupMembersUpdateObsolete'] = _UPDATEGROUPMEMBERSUPDATEOBSOLETE
DESCRIPTOR.message_types_by_name['UpdateGroupTitleChangedObsolete'] = _UPDATEGROUPTITLECHANGEDOBSOLETE
DESCRIPTOR.message_types_by_name['UpdateGroupTopicChangedObsolete'] = _UPDATEGROUPTOPICCHANGEDOBSOLETE
DESCRIPTOR.message_types_by_name['UpdateGroupAboutChangedObsolete'] = _UPDATEGROUPABOUTCHANGEDOBSOLETE
DESCRIPTOR.message_types_by_name['UpdateGroupAvatarChangedObsolete'] = _UPDATEGROUPAVATARCHANGEDOBSOLETE
DESCRIPTOR.message_types_by_name['UpdateGroupShortnameChanged'] = _UPDATEGROUPSHORTNAMECHANGED
DESCRIPTOR.enum_types_by_name['GroupType'] = _GROUPTYPE
DESCRIPTOR.enum_types_by_name['GroupAdminPermission'] = _GROUPADMINPERMISSION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Member = _reflection.GeneratedProtocolMessageType('Member', (_message.Message,), dict(
  DESCRIPTOR = _MEMBER,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.Member)
  ))
_sym_db.RegisterMessage(Member)

Group = _reflection.GeneratedProtocolMessageType('Group', (_message.Message,), dict(
  DESCRIPTOR = _GROUP,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.Group)
  ))
_sym_db.RegisterMessage(Group)

GroupFull = _reflection.GeneratedProtocolMessageType('GroupFull', (_message.Message,), dict(
  DESCRIPTOR = _GROUPFULL,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.GroupFull)
  ))
_sym_db.RegisterMessage(GroupFull)

RequestLoadFullGroups = _reflection.GeneratedProtocolMessageType('RequestLoadFullGroups', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTLOADFULLGROUPS,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestLoadFullGroups)
  ))
_sym_db.RegisterMessage(RequestLoadFullGroups)

ResponseLoadFullGroups = _reflection.GeneratedProtocolMessageType('ResponseLoadFullGroups', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSELOADFULLGROUPS,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseLoadFullGroups)
  ))
_sym_db.RegisterMessage(ResponseLoadFullGroups)

RequestLoadMembers = _reflection.GeneratedProtocolMessageType('RequestLoadMembers', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTLOADMEMBERS,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestLoadMembers)
  ))
_sym_db.RegisterMessage(RequestLoadMembers)

ResponseLoadMembers = _reflection.GeneratedProtocolMessageType('ResponseLoadMembers', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSELOADMEMBERS,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseLoadMembers)
  ))
_sym_db.RegisterMessage(ResponseLoadMembers)

UpdateGroupTitleChanged = _reflection.GeneratedProtocolMessageType('UpdateGroupTitleChanged', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEGROUPTITLECHANGED,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateGroupTitleChanged)
  ))
_sym_db.RegisterMessage(UpdateGroupTitleChanged)

UpdateGroupAvatarChanged = _reflection.GeneratedProtocolMessageType('UpdateGroupAvatarChanged', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEGROUPAVATARCHANGED,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateGroupAvatarChanged)
  ))
_sym_db.RegisterMessage(UpdateGroupAvatarChanged)

UpdateGroupTopicChanged = _reflection.GeneratedProtocolMessageType('UpdateGroupTopicChanged', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEGROUPTOPICCHANGED,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateGroupTopicChanged)
  ))
_sym_db.RegisterMessage(UpdateGroupTopicChanged)

UpdateGroupAboutChanged = _reflection.GeneratedProtocolMessageType('UpdateGroupAboutChanged', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEGROUPABOUTCHANGED,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateGroupAboutChanged)
  ))
_sym_db.RegisterMessage(UpdateGroupAboutChanged)

UpdateGroupOwnerChanged = _reflection.GeneratedProtocolMessageType('UpdateGroupOwnerChanged', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEGROUPOWNERCHANGED,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateGroupOwnerChanged)
  ))
_sym_db.RegisterMessage(UpdateGroupOwnerChanged)

UpdateGroupHistoryShared = _reflection.GeneratedProtocolMessageType('UpdateGroupHistoryShared', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEGROUPHISTORYSHARED,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateGroupHistoryShared)
  ))
_sym_db.RegisterMessage(UpdateGroupHistoryShared)

UpdateGroupCanSendMessagesChanged = _reflection.GeneratedProtocolMessageType('UpdateGroupCanSendMessagesChanged', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEGROUPCANSENDMESSAGESCHANGED,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateGroupCanSendMessagesChanged)
  ))
_sym_db.RegisterMessage(UpdateGroupCanSendMessagesChanged)

UpdateGroupCanViewMembersChanged = _reflection.GeneratedProtocolMessageType('UpdateGroupCanViewMembersChanged', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEGROUPCANVIEWMEMBERSCHANGED,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateGroupCanViewMembersChanged)
  ))
_sym_db.RegisterMessage(UpdateGroupCanViewMembersChanged)

UpdateGroupCanInviteMembersChanged = _reflection.GeneratedProtocolMessageType('UpdateGroupCanInviteMembersChanged', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEGROUPCANINVITEMEMBERSCHANGED,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateGroupCanInviteMembersChanged)
  ))
_sym_db.RegisterMessage(UpdateGroupCanInviteMembersChanged)

UpdateGroupMemberChanged = _reflection.GeneratedProtocolMessageType('UpdateGroupMemberChanged', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEGROUPMEMBERCHANGED,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateGroupMemberChanged)
  ))
_sym_db.RegisterMessage(UpdateGroupMemberChanged)

UpdateGroupMembersBecameAsync = _reflection.GeneratedProtocolMessageType('UpdateGroupMembersBecameAsync', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEGROUPMEMBERSBECAMEASYNC,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateGroupMembersBecameAsync)
  ))
_sym_db.RegisterMessage(UpdateGroupMembersBecameAsync)

UpdateGroupMembersUpdated = _reflection.GeneratedProtocolMessageType('UpdateGroupMembersUpdated', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEGROUPMEMBERSUPDATED,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateGroupMembersUpdated)
  ))
_sym_db.RegisterMessage(UpdateGroupMembersUpdated)

UpdateGroupMemberDiff = _reflection.GeneratedProtocolMessageType('UpdateGroupMemberDiff', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEGROUPMEMBERDIFF,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateGroupMemberDiff)
  ))
_sym_db.RegisterMessage(UpdateGroupMemberDiff)

UpdateGroupMembersCountChanged = _reflection.GeneratedProtocolMessageType('UpdateGroupMembersCountChanged', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEGROUPMEMBERSCOUNTCHANGED,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateGroupMembersCountChanged)
  ))
_sym_db.RegisterMessage(UpdateGroupMembersCountChanged)

UpdateGroupMemberAdminChanged = _reflection.GeneratedProtocolMessageType('UpdateGroupMemberAdminChanged', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEGROUPMEMBERADMINCHANGED,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateGroupMemberAdminChanged)
  ))
_sym_db.RegisterMessage(UpdateGroupMemberAdminChanged)

RequestCreateGroup = _reflection.GeneratedProtocolMessageType('RequestCreateGroup', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTCREATEGROUP,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestCreateGroup)
  ))
_sym_db.RegisterMessage(RequestCreateGroup)

ResponseCreateGroup = _reflection.GeneratedProtocolMessageType('ResponseCreateGroup', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSECREATEGROUP,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseCreateGroup)
  ))
_sym_db.RegisterMessage(ResponseCreateGroup)

RequestEditGroupTitle = _reflection.GeneratedProtocolMessageType('RequestEditGroupTitle', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTEDITGROUPTITLE,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestEditGroupTitle)
  ))
_sym_db.RegisterMessage(RequestEditGroupTitle)

RequestSetGroupShortname = _reflection.GeneratedProtocolMessageType('RequestSetGroupShortname', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTSETGROUPSHORTNAME,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestSetGroupShortname)
  ))
_sym_db.RegisterMessage(RequestSetGroupShortname)

RequestEditGroupAvatar = _reflection.GeneratedProtocolMessageType('RequestEditGroupAvatar', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTEDITGROUPAVATAR,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestEditGroupAvatar)
  ))
_sym_db.RegisterMessage(RequestEditGroupAvatar)

ResponseEditGroupAvatar = _reflection.GeneratedProtocolMessageType('ResponseEditGroupAvatar', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSEEDITGROUPAVATAR,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseEditGroupAvatar)
  ))
_sym_db.RegisterMessage(ResponseEditGroupAvatar)

RequestRemoveGroupAvatar = _reflection.GeneratedProtocolMessageType('RequestRemoveGroupAvatar', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTREMOVEGROUPAVATAR,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestRemoveGroupAvatar)
  ))
_sym_db.RegisterMessage(RequestRemoveGroupAvatar)

RequestEditGroupTopic = _reflection.GeneratedProtocolMessageType('RequestEditGroupTopic', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTEDITGROUPTOPIC,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestEditGroupTopic)
  ))
_sym_db.RegisterMessage(RequestEditGroupTopic)

RequestEditGroupAbout = _reflection.GeneratedProtocolMessageType('RequestEditGroupAbout', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTEDITGROUPABOUT,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestEditGroupAbout)
  ))
_sym_db.RegisterMessage(RequestEditGroupAbout)

RequestInviteUser = _reflection.GeneratedProtocolMessageType('RequestInviteUser', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTINVITEUSER,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestInviteUser)
  ))
_sym_db.RegisterMessage(RequestInviteUser)

RequestLeaveGroup = _reflection.GeneratedProtocolMessageType('RequestLeaveGroup', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTLEAVEGROUP,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestLeaveGroup)
  ))
_sym_db.RegisterMessage(RequestLeaveGroup)

RequestKickUser = _reflection.GeneratedProtocolMessageType('RequestKickUser', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTKICKUSER,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestKickUser)
  ))
_sym_db.RegisterMessage(RequestKickUser)

RequestMakeUserAdmin = _reflection.GeneratedProtocolMessageType('RequestMakeUserAdmin', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTMAKEUSERADMIN,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestMakeUserAdmin)
  ))
_sym_db.RegisterMessage(RequestMakeUserAdmin)

GroupMemberPermission = _reflection.GeneratedProtocolMessageType('GroupMemberPermission', (_message.Message,), dict(
  DESCRIPTOR = _GROUPMEMBERPERMISSION,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.GroupMemberPermission)
  ))
_sym_db.RegisterMessage(GroupMemberPermission)

RequestGetGroupMemberPermissions = _reflection.GeneratedProtocolMessageType('RequestGetGroupMemberPermissions', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTGETGROUPMEMBERPERMISSIONS,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestGetGroupMemberPermissions)
  ))
_sym_db.RegisterMessage(RequestGetGroupMemberPermissions)

ResponseGetGroupMemberPermissions = _reflection.GeneratedProtocolMessageType('ResponseGetGroupMemberPermissions', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSEGETGROUPMEMBERPERMISSIONS,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseGetGroupMemberPermissions)
  ))
_sym_db.RegisterMessage(ResponseGetGroupMemberPermissions)

UpdateGroupMemberPermissionsChanged = _reflection.GeneratedProtocolMessageType('UpdateGroupMemberPermissionsChanged', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEGROUPMEMBERPERMISSIONSCHANGED,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateGroupMemberPermissionsChanged)
  ))
_sym_db.RegisterMessage(UpdateGroupMemberPermissionsChanged)

RequestTransferOwnership = _reflection.GeneratedProtocolMessageType('RequestTransferOwnership', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTTRANSFEROWNERSHIP,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestTransferOwnership)
  ))
_sym_db.RegisterMessage(RequestTransferOwnership)

ResponseInviteUrl = _reflection.GeneratedProtocolMessageType('ResponseInviteUrl', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSEINVITEURL,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseInviteUrl)
  ))
_sym_db.RegisterMessage(ResponseInviteUrl)

RequestGetGroupInviteUrl = _reflection.GeneratedProtocolMessageType('RequestGetGroupInviteUrl', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTGETGROUPINVITEURL,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestGetGroupInviteUrl)
  ))
_sym_db.RegisterMessage(RequestGetGroupInviteUrl)

RequestGetGroupInviteUrlBase = _reflection.GeneratedProtocolMessageType('RequestGetGroupInviteUrlBase', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTGETGROUPINVITEURLBASE,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestGetGroupInviteUrlBase)
  ))
_sym_db.RegisterMessage(RequestGetGroupInviteUrlBase)

ResponseGetGroupInviteUrlBase = _reflection.GeneratedProtocolMessageType('ResponseGetGroupInviteUrlBase', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSEGETGROUPINVITEURLBASE,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseGetGroupInviteUrlBase)
  ))
_sym_db.RegisterMessage(ResponseGetGroupInviteUrlBase)

RequestRevokeInviteUrl = _reflection.GeneratedProtocolMessageType('RequestRevokeInviteUrl', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTREVOKEINVITEURL,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestRevokeInviteUrl)
  ))
_sym_db.RegisterMessage(RequestRevokeInviteUrl)

RequestJoinGroup = _reflection.GeneratedProtocolMessageType('RequestJoinGroup', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTJOINGROUP,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestJoinGroup)
  ))
_sym_db.RegisterMessage(RequestJoinGroup)

ResponseJoinGroup = _reflection.GeneratedProtocolMessageType('ResponseJoinGroup', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSEJOINGROUP,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseJoinGroup)
  ))
_sym_db.RegisterMessage(ResponseJoinGroup)

RequestJoinGroupByPeer = _reflection.GeneratedProtocolMessageType('RequestJoinGroupByPeer', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTJOINGROUPBYPEER,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestJoinGroupByPeer)
  ))
_sym_db.RegisterMessage(RequestJoinGroupByPeer)

RequestMakeUserAdminObsolete = _reflection.GeneratedProtocolMessageType('RequestMakeUserAdminObsolete', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTMAKEUSERADMINOBSOLETE,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestMakeUserAdminObsolete)
  ))
_sym_db.RegisterMessage(RequestMakeUserAdminObsolete)

ResponseMakeUserAdminObsolete = _reflection.GeneratedProtocolMessageType('ResponseMakeUserAdminObsolete', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSEMAKEUSERADMINOBSOLETE,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseMakeUserAdminObsolete)
  ))
_sym_db.RegisterMessage(ResponseMakeUserAdminObsolete)

UpdateGroupInviteObsolete = _reflection.GeneratedProtocolMessageType('UpdateGroupInviteObsolete', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEGROUPINVITEOBSOLETE,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateGroupInviteObsolete)
  ))
_sym_db.RegisterMessage(UpdateGroupInviteObsolete)

UpdateGroupUserInvitedObsolete = _reflection.GeneratedProtocolMessageType('UpdateGroupUserInvitedObsolete', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEGROUPUSERINVITEDOBSOLETE,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateGroupUserInvitedObsolete)
  ))
_sym_db.RegisterMessage(UpdateGroupUserInvitedObsolete)

UpdateGroupUserLeaveObsolete = _reflection.GeneratedProtocolMessageType('UpdateGroupUserLeaveObsolete', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEGROUPUSERLEAVEOBSOLETE,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateGroupUserLeaveObsolete)
  ))
_sym_db.RegisterMessage(UpdateGroupUserLeaveObsolete)

UpdateGroupUserKickObsolete = _reflection.GeneratedProtocolMessageType('UpdateGroupUserKickObsolete', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEGROUPUSERKICKOBSOLETE,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateGroupUserKickObsolete)
  ))
_sym_db.RegisterMessage(UpdateGroupUserKickObsolete)

UpdateGroupMembersUpdateObsolete = _reflection.GeneratedProtocolMessageType('UpdateGroupMembersUpdateObsolete', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEGROUPMEMBERSUPDATEOBSOLETE,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateGroupMembersUpdateObsolete)
  ))
_sym_db.RegisterMessage(UpdateGroupMembersUpdateObsolete)

UpdateGroupTitleChangedObsolete = _reflection.GeneratedProtocolMessageType('UpdateGroupTitleChangedObsolete', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEGROUPTITLECHANGEDOBSOLETE,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateGroupTitleChangedObsolete)
  ))
_sym_db.RegisterMessage(UpdateGroupTitleChangedObsolete)

UpdateGroupTopicChangedObsolete = _reflection.GeneratedProtocolMessageType('UpdateGroupTopicChangedObsolete', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEGROUPTOPICCHANGEDOBSOLETE,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateGroupTopicChangedObsolete)
  ))
_sym_db.RegisterMessage(UpdateGroupTopicChangedObsolete)

UpdateGroupAboutChangedObsolete = _reflection.GeneratedProtocolMessageType('UpdateGroupAboutChangedObsolete', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEGROUPABOUTCHANGEDOBSOLETE,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateGroupAboutChangedObsolete)
  ))
_sym_db.RegisterMessage(UpdateGroupAboutChangedObsolete)

UpdateGroupAvatarChangedObsolete = _reflection.GeneratedProtocolMessageType('UpdateGroupAvatarChangedObsolete', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEGROUPAVATARCHANGEDOBSOLETE,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateGroupAvatarChangedObsolete)
  ))
_sym_db.RegisterMessage(UpdateGroupAvatarChangedObsolete)

UpdateGroupShortnameChanged = _reflection.GeneratedProtocolMessageType('UpdateGroupShortnameChanged', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEGROUPSHORTNAMECHANGED,
  __module__ = 'groups_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateGroupShortnameChanged)
  ))
_sym_db.RegisterMessage(UpdateGroupShortnameChanged)


DESCRIPTOR._options = None
_MEMBER.fields_by_name['uid']._options = None
_MEMBER.fields_by_name['inviter_uid']._options = None
_MEMBER.fields_by_name['date']._options = None
_MEMBER.fields_by_name['is_admin']._options = None
_MEMBER.fields_by_name['permissions']._options = None
_GROUP.fields_by_name['id']._options = None
_GROUP.fields_by_name['access_hash']._options = None
_GROUP.fields_by_name['title']._options = None
_GROUP.fields_by_name['avatar']._options = None
_GROUP.fields_by_name['members_amount']._options = None
_GROUP.fields_by_name['is_member']._options = None
_GROUP.fields_by_name['is_hidden']._options = None
_GROUP.fields_by_name['group_type']._options = None
_GROUP.fields_by_name['can_send_message']._options = None
_GROUP.fields_by_name['is_admin']._options = None
_GROUP.fields_by_name['creator_uid']._options = None
_GROUP.fields_by_name['members']._options = None
_GROUP.fields_by_name['create_date']._options = None
_GROUP.fields_by_name['theme']._options = None
_GROUP.fields_by_name['about']._options = None
_GROUP.fields_by_name['shortname']._options = None
_GROUPFULL.fields_by_name['id']._options = None
_GROUPFULL.fields_by_name['create_date']._options = None
_GROUPFULL.fields_by_name['owner_uid']._options = None
_GROUPFULL.fields_by_name['members']._options = None
_GROUPFULL.fields_by_name['theme']._options = None
_GROUPFULL.fields_by_name['about']._options = None
_GROUPFULL.fields_by_name['is_async_members']._options = None
_GROUPFULL.fields_by_name['can_view_members']._options = None
_GROUPFULL.fields_by_name['can_invite_people']._options = None
_GROUPFULL.fields_by_name['is_shared_history']._options = None
_REQUESTLOADFULLGROUPS.fields_by_name['groups']._options = None
_REQUESTLOADFULLGROUPS._options = None
_RESPONSELOADFULLGROUPS._options = None
_REQUESTLOADMEMBERS.fields_by_name['group']._options = None
_REQUESTLOADMEMBERS.fields_by_name['limit']._options = None
_REQUESTLOADMEMBERS.fields_by_name['next']._options = None
_REQUESTLOADMEMBERS._options = None
_RESPONSELOADMEMBERS._options = None
_UPDATEGROUPTITLECHANGED.fields_by_name['group_id']._options = None
_UPDATEGROUPTITLECHANGED.fields_by_name['title']._options = None
_UPDATEGROUPAVATARCHANGED.fields_by_name['group_id']._options = None
_UPDATEGROUPAVATARCHANGED.fields_by_name['avatar']._options = None
_UPDATEGROUPTOPICCHANGED.fields_by_name['group_id']._options = None
_UPDATEGROUPTOPICCHANGED.fields_by_name['topic']._options = None
_UPDATEGROUPABOUTCHANGED.fields_by_name['group_id']._options = None
_UPDATEGROUPABOUTCHANGED.fields_by_name['about']._options = None
_UPDATEGROUPOWNERCHANGED.fields_by_name['group_id']._options = None
_UPDATEGROUPOWNERCHANGED.fields_by_name['user_id']._options = None
_UPDATEGROUPHISTORYSHARED.fields_by_name['group_id']._options = None
_UPDATEGROUPCANSENDMESSAGESCHANGED.fields_by_name['group_id']._options = None
_UPDATEGROUPCANSENDMESSAGESCHANGED.fields_by_name['can_send_messages']._options = None
_UPDATEGROUPCANVIEWMEMBERSCHANGED.fields_by_name['group_id']._options = None
_UPDATEGROUPCANVIEWMEMBERSCHANGED.fields_by_name['can_view_members']._options = None
_UPDATEGROUPCANINVITEMEMBERSCHANGED.fields_by_name['group_id']._options = None
_UPDATEGROUPCANINVITEMEMBERSCHANGED.fields_by_name['can_invite_members']._options = None
_UPDATEGROUPMEMBERCHANGED.fields_by_name['group_id']._options = None
_UPDATEGROUPMEMBERCHANGED.fields_by_name['is_member']._options = None
_UPDATEGROUPMEMBERSBECAMEASYNC.fields_by_name['group_id']._options = None
_UPDATEGROUPMEMBERSUPDATED.fields_by_name['group_id']._options = None
_UPDATEGROUPMEMBERSUPDATED.fields_by_name['members']._options = None
_UPDATEGROUPMEMBERDIFF.fields_by_name['removed_users']._options = None
_UPDATEGROUPMEMBERDIFF.fields_by_name['added_members']._options = None
_UPDATEGROUPMEMBERDIFF.fields_by_name['members_count']._options = None
_UPDATEGROUPMEMBERSCOUNTCHANGED.fields_by_name['group_id']._options = None
_UPDATEGROUPMEMBERSCOUNTCHANGED.fields_by_name['members_count']._options = None
_UPDATEGROUPMEMBERADMINCHANGED.fields_by_name['group_id']._options = None
_UPDATEGROUPMEMBERADMINCHANGED.fields_by_name['user_id']._options = None
_UPDATEGROUPMEMBERADMINCHANGED.fields_by_name['is_admin']._options = None
_REQUESTCREATEGROUP.fields_by_name['rid']._options = None
_REQUESTCREATEGROUP.fields_by_name['title']._options = None
_REQUESTCREATEGROUP.fields_by_name['users']._options = None
_REQUESTCREATEGROUP.fields_by_name['group_type']._options = None
_REQUESTCREATEGROUP.fields_by_name['username']._options = None
_REQUESTCREATEGROUP.fields_by_name['optimizations']._options = None
_REQUESTCREATEGROUP._options = None
_RESPONSECREATEGROUP._options = None
_REQUESTEDITGROUPTITLE.fields_by_name['group_peer']._options = None
_REQUESTEDITGROUPTITLE.fields_by_name['rid']._options = None
_REQUESTEDITGROUPTITLE.fields_by_name['title']._options = None
_REQUESTEDITGROUPTITLE.fields_by_name['optimizations']._options = None
_REQUESTEDITGROUPTITLE._options = None
_REQUESTSETGROUPSHORTNAME.fields_by_name['peer']._options = None
_REQUESTSETGROUPSHORTNAME.fields_by_name['shortname']._options = None
_REQUESTSETGROUPSHORTNAME._options = None
_REQUESTEDITGROUPAVATAR.fields_by_name['group_peer']._options = None
_REQUESTEDITGROUPAVATAR.fields_by_name['rid']._options = None
_REQUESTEDITGROUPAVATAR.fields_by_name['file_location']._options = None
_REQUESTEDITGROUPAVATAR.fields_by_name['optimizations']._options = None
_REQUESTEDITGROUPAVATAR._options = None
_RESPONSEEDITGROUPAVATAR._options = None
_REQUESTREMOVEGROUPAVATAR.fields_by_name['group_peer']._options = None
_REQUESTREMOVEGROUPAVATAR.fields_by_name['rid']._options = None
_REQUESTREMOVEGROUPAVATAR.fields_by_name['optimizations']._options = None
_REQUESTREMOVEGROUPAVATAR._options = None
_REQUESTEDITGROUPTOPIC.fields_by_name['group_peer']._options = None
_REQUESTEDITGROUPTOPIC.fields_by_name['rid']._options = None
_REQUESTEDITGROUPTOPIC.fields_by_name['topic']._options = None
_REQUESTEDITGROUPTOPIC.fields_by_name['optimizations']._options = None
_REQUESTEDITGROUPTOPIC._options = None
_REQUESTEDITGROUPABOUT.fields_by_name['group_peer']._options = None
_REQUESTEDITGROUPABOUT.fields_by_name['rid']._options = None
_REQUESTEDITGROUPABOUT.fields_by_name['about']._options = None
_REQUESTEDITGROUPABOUT.fields_by_name['optimizations']._options = None
_REQUESTEDITGROUPABOUT._options = None
_REQUESTINVITEUSER.fields_by_name['group_peer']._options = None
_REQUESTINVITEUSER.fields_by_name['rid']._options = None
_REQUESTINVITEUSER.fields_by_name['user']._options = None
_REQUESTINVITEUSER.fields_by_name['optimizations']._options = None
_REQUESTINVITEUSER._options = None
_REQUESTLEAVEGROUP.fields_by_name['group_peer']._options = None
_REQUESTLEAVEGROUP.fields_by_name['rid']._options = None
_REQUESTLEAVEGROUP.fields_by_name['optimizations']._options = None
_REQUESTLEAVEGROUP._options = None
_REQUESTKICKUSER.fields_by_name['group_peer']._options = None
_REQUESTKICKUSER.fields_by_name['rid']._options = None
_REQUESTKICKUSER.fields_by_name['user']._options = None
_REQUESTKICKUSER.fields_by_name['optimizations']._options = None
_REQUESTKICKUSER._options = None
_REQUESTMAKEUSERADMIN.fields_by_name['group_peer']._options = None
_REQUESTMAKEUSERADMIN.fields_by_name['user_peer']._options = None
_REQUESTMAKEUSERADMIN.fields_by_name['permissions']._options = None
_REQUESTMAKEUSERADMIN._options = None
_GROUPMEMBERPERMISSION.fields_by_name['user_id']._options = None
_GROUPMEMBERPERMISSION.fields_by_name['permissions']._options = None
_REQUESTGETGROUPMEMBERPERMISSIONS.fields_by_name['group_id']._options = None
_REQUESTGETGROUPMEMBERPERMISSIONS.fields_by_name['user_ids']._options = None
_REQUESTGETGROUPMEMBERPERMISSIONS._options = None
_RESPONSEGETGROUPMEMBERPERMISSIONS._options = None
_UPDATEGROUPMEMBERPERMISSIONSCHANGED.fields_by_name['group_id']._options = None
_UPDATEGROUPMEMBERPERMISSIONSCHANGED.fields_by_name['user_id']._options = None
_UPDATEGROUPMEMBERPERMISSIONSCHANGED.fields_by_name['permissions']._options = None
_REQUESTTRANSFEROWNERSHIP.fields_by_name['group_peer']._options = None
_REQUESTTRANSFEROWNERSHIP.fields_by_name['new_owner']._options = None
_REQUESTTRANSFEROWNERSHIP._options = None
_RESPONSEINVITEURL._options = None
_REQUESTGETGROUPINVITEURL.fields_by_name['group_peer']._options = None
_REQUESTGETGROUPINVITEURL._options = None
_REQUESTGETGROUPINVITEURLBASE._options = None
_RESPONSEGETGROUPINVITEURLBASE._options = None
_REQUESTREVOKEINVITEURL.fields_by_name['group_peer']._options = None
_REQUESTREVOKEINVITEURL._options = None
_REQUESTJOINGROUP.fields_by_name['token']._options = None
_REQUESTJOINGROUP.fields_by_name['optimizations']._options = None
_REQUESTJOINGROUP._options = None
_RESPONSEJOINGROUP._options = None
_REQUESTJOINGROUPBYPEER.fields_by_name['peer']._options = None
_REQUESTJOINGROUPBYPEER._options = None
_REQUESTMAKEUSERADMINOBSOLETE.fields_by_name['group_peer']._options = None
_REQUESTMAKEUSERADMINOBSOLETE.fields_by_name['user_peer']._options = None
_REQUESTMAKEUSERADMINOBSOLETE._options = None
_RESPONSEMAKEUSERADMINOBSOLETE._options = None
_UPDATEGROUPINVITEOBSOLETE.fields_by_name['group_id']._options = None
_UPDATEGROUPINVITEOBSOLETE.fields_by_name['rid']._options = None
_UPDATEGROUPINVITEOBSOLETE.fields_by_name['invite_uid']._options = None
_UPDATEGROUPINVITEOBSOLETE.fields_by_name['date']._options = None
_UPDATEGROUPUSERINVITEDOBSOLETE.fields_by_name['group_id']._options = None
_UPDATEGROUPUSERINVITEDOBSOLETE.fields_by_name['rid']._options = None
_UPDATEGROUPUSERINVITEDOBSOLETE.fields_by_name['mid']._options = None
_UPDATEGROUPUSERINVITEDOBSOLETE.fields_by_name['uid']._options = None
_UPDATEGROUPUSERINVITEDOBSOLETE.fields_by_name['inviter_uid']._options = None
_UPDATEGROUPUSERINVITEDOBSOLETE.fields_by_name['date']._options = None
_UPDATEGROUPUSERLEAVEOBSOLETE.fields_by_name['group_id']._options = None
_UPDATEGROUPUSERLEAVEOBSOLETE.fields_by_name['uid']._options = None
_UPDATEGROUPUSERLEAVEOBSOLETE.fields_by_name['date']._options = None
_UPDATEGROUPUSERKICKOBSOLETE.fields_by_name['group_id']._options = None
_UPDATEGROUPUSERKICKOBSOLETE.fields_by_name['uid']._options = None
_UPDATEGROUPUSERKICKOBSOLETE.fields_by_name['kicker_uid']._options = None
_UPDATEGROUPUSERKICKOBSOLETE.fields_by_name['date']._options = None
_UPDATEGROUPMEMBERSUPDATEOBSOLETE.fields_by_name['group_id']._options = None
_UPDATEGROUPMEMBERSUPDATEOBSOLETE.fields_by_name['members']._options = None
_UPDATEGROUPTITLECHANGEDOBSOLETE.fields_by_name['group_id']._options = None
_UPDATEGROUPTITLECHANGEDOBSOLETE.fields_by_name['uid']._options = None
_UPDATEGROUPTITLECHANGEDOBSOLETE.fields_by_name['title']._options = None
_UPDATEGROUPTITLECHANGEDOBSOLETE.fields_by_name['date']._options = None
_UPDATEGROUPTOPICCHANGEDOBSOLETE.fields_by_name['group_id']._options = None
_UPDATEGROUPTOPICCHANGEDOBSOLETE.fields_by_name['rid']._options = None
_UPDATEGROUPTOPICCHANGEDOBSOLETE.fields_by_name['uid']._options = None
_UPDATEGROUPTOPICCHANGEDOBSOLETE.fields_by_name['topic']._options = None
_UPDATEGROUPTOPICCHANGEDOBSOLETE.fields_by_name['date']._options = None
_UPDATEGROUPABOUTCHANGEDOBSOLETE.fields_by_name['group_id']._options = None
_UPDATEGROUPABOUTCHANGEDOBSOLETE.fields_by_name['about']._options = None
_UPDATEGROUPAVATARCHANGEDOBSOLETE.fields_by_name['group_id']._options = None
_UPDATEGROUPAVATARCHANGEDOBSOLETE.fields_by_name['uid']._options = None
_UPDATEGROUPAVATARCHANGEDOBSOLETE.fields_by_name['avatar']._options = None
_UPDATEGROUPAVATARCHANGEDOBSOLETE.fields_by_name['date']._options = None
_UPDATEGROUPSHORTNAMECHANGED.fields_by_name['group_id']._options = None
_UPDATEGROUPSHORTNAMECHANGED.fields_by_name['shortname']._options = None
_UPDATEGROUPSHORTNAMECHANGED.fields_by_name['uid']._options = None

_GROUPS = _descriptor.ServiceDescriptor(
  name='Groups',
  full_name='dialog.Groups',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=11195,
  serialized_end=13788,
  methods=[
  _descriptor.MethodDescriptor(
    name='LoadFullGroups',
    full_name='dialog.Groups.LoadFullGroups',
    index=0,
    containing_service=None,
    input_type=_REQUESTLOADFULLGROUPS,
    output_type=_RESPONSELOADFULLGROUPS,
    serialized_options=_b('\202\323\344\223\002#\"\036/v1/grpc/Groups/LoadFullGroups:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='LoadMembers',
    full_name='dialog.Groups.LoadMembers',
    index=1,
    containing_service=None,
    input_type=_REQUESTLOADMEMBERS,
    output_type=_RESPONSELOADMEMBERS,
    serialized_options=_b('\202\323\344\223\002 \"\033/v1/grpc/Groups/LoadMembers:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='CreateGroup',
    full_name='dialog.Groups.CreateGroup',
    index=2,
    containing_service=None,
    input_type=_REQUESTCREATEGROUP,
    output_type=_RESPONSECREATEGROUP,
    serialized_options=_b('\202\323\344\223\002 \"\033/v1/grpc/Groups/CreateGroup:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='EditGroupTitle',
    full_name='dialog.Groups.EditGroupTitle',
    index=3,
    containing_service=None,
    input_type=_REQUESTEDITGROUPTITLE,
    output_type=miscellaneous__pb2._RESPONSESEQDATEMID,
    serialized_options=_b('\202\323\344\223\002#\"\036/v1/grpc/Groups/EditGroupTitle:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='SetGroupShortname',
    full_name='dialog.Groups.SetGroupShortname',
    index=4,
    containing_service=None,
    input_type=_REQUESTSETGROUPSHORTNAME,
    output_type=miscellaneous__pb2._RESPONSESEQ,
    serialized_options=_b('\202\323\344\223\002&\"!/v1/grpc/Groups/SetGroupShortname:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='EditGroupAvatar',
    full_name='dialog.Groups.EditGroupAvatar',
    index=5,
    containing_service=None,
    input_type=_REQUESTEDITGROUPAVATAR,
    output_type=_RESPONSEEDITGROUPAVATAR,
    serialized_options=_b('\202\323\344\223\002$\"\037/v1/grpc/Groups/EditGroupAvatar:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='RemoveGroupAvatar',
    full_name='dialog.Groups.RemoveGroupAvatar',
    index=6,
    containing_service=None,
    input_type=_REQUESTREMOVEGROUPAVATAR,
    output_type=miscellaneous__pb2._RESPONSESEQDATEMID,
    serialized_options=_b('\202\323\344\223\002&\"!/v1/grpc/Groups/RemoveGroupAvatar:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='EditGroupTopic',
    full_name='dialog.Groups.EditGroupTopic',
    index=7,
    containing_service=None,
    input_type=_REQUESTEDITGROUPTOPIC,
    output_type=miscellaneous__pb2._RESPONSESEQDATE,
    serialized_options=_b('\202\323\344\223\002#\"\036/v1/grpc/Groups/EditGroupTopic:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='EditGroupAbout',
    full_name='dialog.Groups.EditGroupAbout',
    index=8,
    containing_service=None,
    input_type=_REQUESTEDITGROUPABOUT,
    output_type=miscellaneous__pb2._RESPONSESEQDATE,
    serialized_options=_b('\202\323\344\223\002#\"\036/v1/grpc/Groups/EditGroupAbout:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='InviteUser',
    full_name='dialog.Groups.InviteUser',
    index=9,
    containing_service=None,
    input_type=_REQUESTINVITEUSER,
    output_type=miscellaneous__pb2._RESPONSESEQDATEMID,
    serialized_options=_b('\202\323\344\223\002\037\"\032/v1/grpc/Groups/InviteUser:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='LeaveGroup',
    full_name='dialog.Groups.LeaveGroup',
    index=10,
    containing_service=None,
    input_type=_REQUESTLEAVEGROUP,
    output_type=miscellaneous__pb2._RESPONSESEQDATEMID,
    serialized_options=_b('\202\323\344\223\002\037\"\032/v1/grpc/Groups/LeaveGroup:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='KickUser',
    full_name='dialog.Groups.KickUser',
    index=11,
    containing_service=None,
    input_type=_REQUESTKICKUSER,
    output_type=miscellaneous__pb2._RESPONSESEQDATEMID,
    serialized_options=_b('\202\323\344\223\002\035\"\030/v1/grpc/Groups/KickUser:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='MakeUserAdmin',
    full_name='dialog.Groups.MakeUserAdmin',
    index=12,
    containing_service=None,
    input_type=_REQUESTMAKEUSERADMIN,
    output_type=miscellaneous__pb2._RESPONSESEQDATE,
    serialized_options=_b('\202\323\344\223\002\"\"\035/v1/grpc/Groups/MakeUserAdmin:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='GetGroupMemberPermissions',
    full_name='dialog.Groups.GetGroupMemberPermissions',
    index=13,
    containing_service=None,
    input_type=_REQUESTGETGROUPMEMBERPERMISSIONS,
    output_type=_RESPONSEGETGROUPMEMBERPERMISSIONS,
    serialized_options=_b('\202\323\344\223\002.\")/v1/grpc/Groups/GetGroupMemberPermissions:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='TransferOwnership',
    full_name='dialog.Groups.TransferOwnership',
    index=14,
    containing_service=None,
    input_type=_REQUESTTRANSFEROWNERSHIP,
    output_type=miscellaneous__pb2._RESPONSESEQDATE,
    serialized_options=_b('\202\323\344\223\002&\"!/v1/grpc/Groups/TransferOwnership:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='GetGroupInviteUrl',
    full_name='dialog.Groups.GetGroupInviteUrl',
    index=15,
    containing_service=None,
    input_type=_REQUESTGETGROUPINVITEURL,
    output_type=_RESPONSEINVITEURL,
    serialized_options=_b('\202\323\344\223\002&\"!/v1/grpc/Groups/GetGroupInviteUrl:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='GetGroupInviteUrlBase',
    full_name='dialog.Groups.GetGroupInviteUrlBase',
    index=16,
    containing_service=None,
    input_type=_REQUESTGETGROUPINVITEURLBASE,
    output_type=_RESPONSEGETGROUPINVITEURLBASE,
    serialized_options=_b('\202\323\344\223\002*\"%/v1/grpc/Groups/GetGroupInviteUrlBase:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='RevokeInviteUrl',
    full_name='dialog.Groups.RevokeInviteUrl',
    index=17,
    containing_service=None,
    input_type=_REQUESTREVOKEINVITEURL,
    output_type=_RESPONSEINVITEURL,
    serialized_options=_b('\202\323\344\223\002$\"\037/v1/grpc/Groups/RevokeInviteUrl:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='JoinGroup',
    full_name='dialog.Groups.JoinGroup',
    index=18,
    containing_service=None,
    input_type=_REQUESTJOINGROUP,
    output_type=_RESPONSEJOINGROUP,
    serialized_options=_b('\202\323\344\223\002\036\"\031/v1/grpc/Groups/JoinGroup:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='JoinGroupByPeer',
    full_name='dialog.Groups.JoinGroupByPeer',
    index=19,
    containing_service=None,
    input_type=_REQUESTJOINGROUPBYPEER,
    output_type=miscellaneous__pb2._RESPONSEVOID,
    serialized_options=_b('\202\323\344\223\002$\"\037/v1/grpc/Groups/JoinGroupByPeer:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='MakeUserAdminObsolete',
    full_name='dialog.Groups.MakeUserAdminObsolete',
    index=20,
    containing_service=None,
    input_type=_REQUESTMAKEUSERADMINOBSOLETE,
    output_type=_RESPONSEMAKEUSERADMINOBSOLETE,
    serialized_options=_b('\202\323\344\223\002*\"%/v1/grpc/Groups/MakeUserAdminObsolete:\001*'),
  ),
])
_sym_db.RegisterServiceDescriptor(_GROUPS)

DESCRIPTOR.services_by_name['Groups'] = _GROUPS

# @@protoc_insertion_point(module_scope)
